<?php
ini_set('memory_limit', '256M');

class Photos {
    private $extended_log = false;
	private $workdir = "";
    private $id = "";
    private $country = "";
    private $useFacialAttributes = true;
    private $date = "";
	private $library_path = false;
	private $database_path = false;
	private $db_link = null;
	private $places_array = array();
	private $persons_array = array();
    private $country_array = array();
	
	public function __construct($workdir, $id, $country, $date, $library_path, $i, $useFacialAttributes) {
        if ($i < 10) {
            $this->extended_log = true;
        }
        
        if (trim($useFacialAttributes) == "true") {
            $this->useFacialAttributes = true;
        } else {
            $this->useFacialAttributes = false;
        }
        
        $this->workdir = trim($workdir);
        @mkdir($this->workdir."/export", 0777, true);
		
		$this->database_path = "/tmp/Library_tmp.apdb";
        
        if (!is_readable($this->database_path)) {
            echo "ERROR! Database does not exist.";
            die();
        }
        
        $this->id = $id;
        $this->country = $country;
        
        echo "LOG: Country \"${country}\"\n";
        
        $this->date = $date;
        $this->library_path = $library_path;
        
		$this->extract_keywords();
		
		//unlink ($this->database_path);
	} 
	
	private function extract_keywords() {
		if ($this->connect_database()) {
			// skapa en array med alla platser
			$handle = $this->db_link->prepare('select DISTINCT defaultName from RKPlace ORDER BY LENGTH(defaultName) DESC');
			$handle->execute();

			$result = $handle->fetchAll(\PDO::FETCH_OBJ);

			if ($result) {
				foreach($result as $row){
					$this->places_array[] = $row->defaultName;
                    $this->log("PLACE:".$row->defaultName);
				}
			}
            
            // skapa en array med alla länder
            $handle = $this->db_link->prepare('select DISTINCT defaultName,countryCode FROM RKPlace WHERE countryCode is not null  ORDER BY LENGTH(defaultName) DESC');
            $handle->execute();
            
            $result = $handle->fetchAll(\PDO::FETCH_OBJ);
            
            if ($result) {
                foreach($result as $row){
                    $this->country_array["".$row->defaultName] = $row->countryCode;
                    $this->log("COUNTRY:".$row->defaultName."(".$row->countryCode.")");
                }
            }
            
            
			
			// skapa en array med alla personer
			$handle = $this->db_link->prepare('select DISTINCT name from RKPerson WHERE name IS NOT NULL ORDER BY LENGTH(name) DESC');
			$handle->execute();

			$result = $handle->fetchAll(\PDO::FETCH_OBJ);

			if ($result) {
				foreach($result as $row){
					$this->persons_array[] = $row->name;
                    $this->log("NAME:".$row->name);
				}
			}
			
			//hämta ut keypath för searchIndexText
			$handle = $this->db_link->prepare('select DISTINCT modelId FROM LiStringAtom WHERE string=?');
			$handle->bindValue(1, "searchIndexText");
			$handle->execute();

			$result = $handle->fetchAll(\PDO::FETCH_OBJ);

			if ($result) {
				foreach($result as $row){
					$keypath = $row->modelId;
				}
			} else {
				echo "Error: no keypath found.";
				die();
			}
			
			echo "keypath:{$keypath}\n";
            
            //Hämtar ut alla personer med identfierade ansikten i bilden
            $face_keywords = array();
            $extract_faces = false;
            
            $handle = $this->db_link->prepare('SELECT name FROM sqlite_master WHERE type="table" AND name="RKFace"');
            $handle->execute();
            $result = $handle->fetchAll(\PDO::FETCH_OBJ);
            
            if (count($result) > 0) {
            	$handle = $this->db_link->prepare('PRAGMA table_info(RKFace)');
           		$handle->execute();
            	$result = $handle->fetchAll(\PDO::FETCH_OBJ);
            	
            	foreach($result as $row){
            		if ($row->name == "imageId") {
            			$extract_faces = true;
            		}
            	}
            }
            
            if ($extract_faces) {
                echo "INFO: RKFace has imageId\n";
                $handle = $this->db_link->prepare('select * from RKFace where isInTrash = ? AND imageId=?');
                $handle->bindValue(1, 0);
                $handle->bindValue(2, $this->id);
                $handle->execute();
                
                $result = $handle->fetchAll(\PDO::FETCH_OBJ);
                
                //var_dump($result);
                if ($result) {
                    $i = 0;
                    $count = count($result);
                    
                    foreach($result as $row){
                        //$this->log($row->modelId." ".$row->uuid);
                        
                        //$version_array[$row->modelId]["uuid"] = $row->uuid;
                        
                        $personId = $row->personId;
                        $hasSmile = $row->hasSmile;
                        $isBlurred = $row->isBlurred;
                        
                        if ($row->isLeftEyeClosed == 0 AND $row->isRightEyeClosed == 0) {
                            $eyesOpen = 1;
                        } else {
                            $eyesOpen = 0;
                        }
                        
                        //echo $personId."\n";
                        
                        $subhandle = $this->db_link->prepare('select name from RKPerson WHERE name IS NOT NULL AND modelId=?');
                        $subhandle->bindValue(1, $personId);
                        $subhandle->execute();
                        
                        $subresult = $subhandle->fetchAll(\PDO::FETCH_OBJ);
                        
                        $name = false;
                        
                        if ($subresult) {
                            foreach($subresult as $subrow){
                                $name = $subrow->name;
                            }
                        }
                        
                        if ($name) {
                            if ($hasSmile == 1) {
                                $face_keywords[] = $name." smiling";
                            } else {
                                $face_keywords[] = $name." not smiling";
                            }
                            
                            if ($eyesOpen == 1) {
                                $face_keywords[] = $name." eyes open";
                            } else {
                                $face_keywords[] = $name." eyes not open";
                            }
                            
                            if ($isBlurred == 1) {
                                $face_keywords[] = $name." blurred";
                            } else {
                                $face_keywords[] = $name." not blurred";
                            }
                        }
                    }
                }
            }
            
			// hämtar ut alla versioner
            //$handle = $this->db_link->prepare('select uuid, modelId from RKVersion where isInTrash = ? LIMIT 1000');
            
            $handle = $this->db_link->prepare('select uuid, modelId, adjustmentUuid from RKVersion where isInTrash = ? AND uuid=?');
			$handle->bindValue(1, 0);
            $handle->bindValue(2, $this->id);
			$handle->execute();

			$result = $handle->fetchAll(\PDO::FETCH_OBJ);

			if ($result) {
                $i = 0;
                $count = count($result);
                
				foreach($result as $row){
					//$this->log($row->modelId." ".$row->uuid);
					
					//$version_array[$row->modelId]["uuid"] = $row->uuid;
					
                    $adjustment_uuid = $row->adjustmentUuid;
                    $modelId = $row->modelId;
					$modelId_hex = dechex($modelId);
                    $modelId_hex_padded = str_pad($modelId_hex, 6, "0", STR_PAD_LEFT);
                    $thumbnail_path = $this->library_path."/resources/proxies/derivatives/".substr($modelId_hex_padded, 2,2)."/".substr($modelId_hex_padded, 0,2)."/".$modelId_hex."/".$adjustment_uuid."_mini_".dechex($modelId).".jpg";
					
					echo "ID:".$row->modelId."\n";
					
					// hämtar ut stringNote för versionen
					$handle = $this->db_link->prepare('select value from RKVersion_stringNote where attachedToId = ? AND keypath = ?');
					$handle->bindValue(1, $row->modelId);
					$handle->bindValue(2, $keypath);
					$handle->execute();

					$subresult = $handle->fetchAll(\PDO::FETCH_OBJ);

					if ($subresult) {
						$keywords = array();
                        foreach($subresult as $subrow){
                            $this->log("StringNote:".$subrow->value);
                            
                            $tmp_keywords = $this->string_to_keywords($subrow->value);
                            
                            sort($tmp_keywords, SORT_NATURAL | SORT_FLAG_CASE);
                            
                            $last_keyword = "";
                            $last_last_keyword = "";
                            
                            foreach ($tmp_keywords as $keyword) {
                                if (strlen($keyword) > 0) {
                                    if (preg_match("/\w/", $keyword)) {
                                        if (!in_array($keyword, $keywords)) {
                                            similar_text($last_keyword, $keyword, $percent);
                                            
                                            if ($this->extended_log) {
                                                echo $last_keyword." vs ".$keyword." = ".$percent."\n";
                                            }
                                            
                                            if ($percent < 75) {
                                                $keywords[] = $keyword;
                                                $last_last_keyword = $last_keyword;
                                                $last_keyword = $keyword;
                                            }
                                        }
                                    }
                                }
                            }
                            
                            if ($this->extended_log) {
                                print_r ($keywords);
                            }
                            //die();
                        }
                        
                        if ($this->country == "location") {
                            foreach ($keywords as $tmp) {
                                if (isset($this->country_array["".$tmp])) {
                                    $this->country = $this->country_array["".$tmp];
                                    echo "Set location of photo to ".$this->country."\n";
                                }
                            }
                        }
                        
						if ($colors_array = $this->get_colors($thumbnail_path)) {
							$keywords = array_merge($keywords,$colors_array);
                        }
                        
                        if ($this->useFacialAttributes) {
                            echo "FACIAL ATTRIBUTES: true\n";
                            print_r ($face_keywords);
                            $keywords = array_merge($keywords, $face_keywords);
                        } else {
                            echo "FACIAL ATTRIBUTES: false\n";
                        }
                        
                        echo "DEBUG: date: ".$this->date."\n";
                        if (is_readable(__DIR__."/holidays/".$this->country."_holidays.xml")) {
                            $holiday_xml = simplexml_load_file(__DIR__."/holidays/".$this->country."_holidays.xml");
                            $holiday_keyword = ($holiday_xml->xpath("//holiday[@date='".$this->date."']/@name")[0]);
                            $keywords[] = $holiday_keyword;
                            echo "HOLIDAY: ". $holiday_keyword."\n";
                        } else {
                            echo "DEBUG: Could not find path: ".__DIR__."/holidays/".$this->country."_holidays.xml\n";
                        }

                        $i++;
                        $percentage = round($i/$count*100);
						//var_dump($keywords);
						echo "\nsave: ".$this->workdir."/export/".$row->uuid."\n";
                        
                        file_put_contents($this->workdir."/export_percentage.txt",$percentage);
                        
						file_put_contents($this->workdir."/export/".$row->uuid,implode("\n", $keywords));
					}
				}
			}           
 		} else {
			echo "ERROR! failed to connect to database.";
			die();
		}
	}

	private function string_to_keywords($value) {
		$keywords = array();
		
		echo $value."\n";
		
		$value = preg_replace("/\([^\)]{0,}\)/", "", $value);
		
		foreach ($this->places_array as $place) {
			//echo $place."\n";
			$new_value = str_replace($place, "", $value);
			
			if ($value != $new_value) {
				$value = $new_value;
				$keywords[] = $place;
			}
			//echo $value."\n";
			
		}
		
		foreach ($this->persons_array as $person) {
			//echo $person."\n";
			$new_value = str_replace($person, "", $value);
			
			if ($value != $new_value) {
				$value = $new_value;
				$keywords[] = $person;
			}
			//echo $value."\n";
		}
		
		if (preg_match("/([\w]{1,}) ((19|20)[0-9]{2})/", $value, $matches)) {
			//var_dump($matches);
			$keywords[] = $matches[1];
			$keywords[] = $matches[2];
			
			$value = str_replace($matches[0], "", $value);
		}
		//
		if (preg_match("/([0-9]{1,} × [0-9]{1,} \([0-9]{1,}\,[0-9]{1,} [MkG]{0,1}P\))/", $value, $matches)) {
			//var_dump($matches);
			$keywords[] = $matches[1];
			
			$value = str_replace($matches[0], "", $value);
		}
		
		
		$value = trim($value);
		//echo "before:".$value."\n";
		// plockar bort filnamn
		$value = preg_replace("/[^ ]{1,}?\.[^ ]{1,}? /", "", $value);
		
		echo "after:".$value."\n";
		
		// plockar bort ord som bar består av gemener och som har minst två mellanslag framför sig, det borde var slaksande saker.
		
		$value = preg_replace("/[ ]{2,}[[:lower:]]+/", "", $value);
		
		
		$value = preg_replace("/([[:lower:]])[ ]{1,}([[:lower:]])/", "$1%%%$2", $value);
		
		$value = preg_replace("/[ ]{1,}/", "&&&", $value);
		
		$value = preg_replace("/%%%/", " ", $value);
		
		$keywords = array_merge($keywords, explode("&&&", $value));
		
		echo $value."\n";
		
		//var_dump($keywords);
		return $keywords;
	}
	
	private function log($string) {
        if ($this->extended_log) {
            echo "LOG : ".$string."\n";
        }
	}
	
	private function connect_database() {
		try {
			$this->db_link = new \PDO("sqlite:".$this->database_path);
			
			$this->db_link->setAttribute(PDO::ATTR_ERRMODE, 
							PDO::ERRMODE_EXCEPTION); 
			return true;
		}
		catch(\PDOException $ex) {
			$this->log($ex->getMessage());
			return false;
		}
	}
	
	private function get_colors($path) {
		$palette = array ("Acadia" => "35312c",
		"Acapulco" => "75aa94",
		"Aero Blue" => "c0e8d5",
		"Affair" => "745085",
		"Afghan Tan" => "905e26",
		"Air Force Blue" => "5d8aa8",
		"Akaroa" => "beb29a",
		"Alabaster" => "f2f0e6",
		"Albescent White" => "e1dacb",
		"Alert Tan" => "954e2c",
		"Alice Blue" => "f0f8ff",
		"Alizarin" => "e32636",
		"Allports" => "1f6a7d",
		"Almond" => "eed9c4",
		"Almond Frost" => "9a8678",
		"Alpine" => "ad8a3b",
		"Alto" => "cdc6c5",
		"Aluminium" => "848789",
		"Amaranth" => "e52b50",
		"Amazon" => "387b54",
		"Amber" => "ffbf00",
		"Americano" => "8a7d72",
		"Amethyst" => "9966cc",
		"Amethyst Smoke" => "95879c",
		"Amour" => "f5e6ea",
		"Amulet" => "7d9d72",
		"Anakiwa" => "8cceea",
		"Antique Brass" => "6c461f",
		"Antique White" => "faebd7",
		"Anzac" => "c68e3f",
		"Apache" => "d3a95c",
		"Apple" => "66b348",
		"Apple Blossom" => "a95249",
		"Apple Green" => "deeadc",
		"Apricot" => "fbceb1",
		"Apricot White" => "f7f0db",
		"Aqua" => "00ffff",
		"Aqua Haze" => "d9ddd5",
		"Aqua Spring" => "e8f3e8",
		"Aqua Squeeze" => "dbe4dc",
		"Aquamarine" => "7fffd4",
		"Arapawa" => "274a5d",
		"Armadillo" => "484a46",
		"Army green" => "4b5320",
		"Arrowtown" => "827a67",
		"Arsenic" => "3b444b",
		"Ash" => "bebaa7",
		"Asparagus" => "7ba05b",
		"Astra" => "edd5a6",
		"Astral" => "376f89",
		"Astronaut" => "445172",
		"Astronaut Blue" => "214559",
		"Athens Grey" => "dcdddd",
		"Aths Special" => "d5cbb2",
		"Atlantis" => "9cd03b",
		"Atoll" => "2b797a",
		"Atomic" => "3d4b52",
		"Atomic Tangerine" => "ff9966",
		"Au Chico" => "9e6759",
		"Aubergine" => "372528",
		"Auburn" => "712f2c",
		"Australian Mint" => "eff8aa",
		"Avocado" => "95986b",
		"Axolotl" => "63775a",
		"Azalea" => "f9c0c4",
		"Aztec" => "293432",
		"Azure" => "f0ffff",
		"Baby Blue" => "6fffff",
		"Bahama Blue" => "25597f",
		"Bahia" => "a9c01c",
		"Baker's Chocolate" => "5c3317",
		"Bali Hai" => "849ca9",
		"Baltic Sea" => "3c3d3e",
		"Banana Mania" => "fbe7b2",
		"Bandicoot" => "878466",
		"Barberry" => "d2c61f",
		"Barley Corn" => "b6935c",
		"Barley White" => "f7e5b7",
		"Barossa" => "452e39",
		"Bastille" => "2c2c32",
		"Battleship Grey" => "51574f",
		"Bay Leaf" => "7bb18d",
		"Bay Of Many" => "353e64",
		"Bazaar" => "8f7777",
		"Beauty Bush" => "ebb9b3",
		"Beaver" => "926f5b",
		"Beeswax" => "e9d7ab",
		"Beige" => "f5f5dc",
		"Bermuda" => "86d2c1",
		"Bermuda Grey" => "6f8c9f",
		"Beryl Green" => "bcbfa8",
		"Bianca" => "f4efe0",
		"Big Stone" => "334046",
		"Bilbao" => "3e8027",
		"Biloba Flower" => "ae99d2",
		"Birch" => "3f3726",
		"Bird Flower" => "d0c117",
		"Biscay" => "2f3c53",
		"Bismark" => "486c7a",
		"Bison Hide" => "b5ac94",
		"Bisque" => "ffe4c4",
		"Bistre" => "3d2b1f",
		"Bitter" => "88896c",
		"Bitter Lemon" => "d2db32",
		"Bittersweet" => "fe6f5e",
		"Bizarre" => "e7d2c8",
		"Black" => "000000",
		"Black Bean" => "232e26",
		"Black Forest" => "2c3227",
		"Black Haze" => "e0ded7",
		"Black Magic" => "332c22",
		"Black Marlin" => "383740",
		"Black Pearl" => "1e272c",
		"Black Rock" => "2c2d3c",
		"Black Rose" => "532934",
		"Black Russian" => "24252b",
		"Black Squeeze" => "e5e6df",
		"Black White" => "e5e4db",
		"Blackberry" => "43182f",
		"Blackcurrant" => "2e183b",
		"Blanc" => "d9d0c1",
		"Blanched Almond" => "ffebcd",
		"Bleach White" => "ebe1ce",
		"Blizzard Blue" => "a3e3ed",
		"Blossom" => "dfb1b6",
		"Blue" => "0000ff",
		"Blue Bayoux" => "62777e",
		"Blue Bell" => "9999cc",
		"Blue Chalk" => "e3d6e9",
		"Blue Charcoal" => "262b2f",
		"Blue Chill" => "408f90",
		"Blue Diamond" => "4b2d72",
		"Blue Dianne" => "35514f",
		"Blue Gem" => "4b3c8e",
		"Blue Haze" => "bdbace",
		"Blue Lagoon" => "00626f",
		"Blue Marguerite" => "6a5bb1",
		"Blue Romance" => "d8f0d2",
		"Blue Smoke" => "78857a",
		"Blue Stone" => "166461",
		"Blue Violet" => "8a2be2",
		"Blue Whale" => "1e3442",
		"Blue Zodiac" => "3c4354",
		"Blumine" => "305c71",
		"Blush" => "b55067",
		"Bokara Grey" => "2a2725",
		"Bole" => "79443b",
		"Bombay" => "aeaead",
		"Bon Jour" => "dfd7d2",
		"Bondi Blue" => "0095b6",
		"Bone" => "dbc2ab",
		"Bordeaux" => "4c1c24",
		"Bossanova" => "4c3d4e",
		"Boston Blue" => "438eac",
		"Botticelli" => "92acb4",
		"Bottle Green" => "254636",
		"Boulder" => "7c817c",
		"Bouquet" => "a78199",
		"Bourbon" => "af6c3e",
		"Bracken" => "5b3d27",
		"Brandy" => "dcb68a",
		"Brandy Punch" => "c07c40",
		"Brandy Rose" => "b6857a",
		"Brass" => "b5a642",
		"Breaker Bay" => "517b78",
		"Brick Red" => "c62d42",
		"Bridal Heath" => "f8ebdd",
		"Bridesmaid" => "fae6df",
		"Bright Green" => "66ff00",
		"Bright Grey" => "57595d",
		"Bright Red" => "922a31",
		"Bright Sun" => "ecbd2c",
		"Bright Turquoise" => "08e8de",
		"Brilliant Rose" => "ff55a3",
		"Brink Pink" => "fb607f",
		"British Racing Green" => "004225",
		"Bronco" => "a79781",
		"Bronze" => "cd7f32",
		"Bronze Olive" => "584c25",
		"Bronzetone" => "434c28",
		"Broom" => "eecc24",
		"Brown" => "a52a2a",
		"Brown Bramble" => "53331e",
		"Brown Derby" => "594537",
		"Brown Pod" => "3c241b",
		"Bubbles" => "e6f2ea",
		"Buccaneer" => "6e5150",
		"Bud" => "a5a88f",
		"Buddha Gold" => "bc9b1b",
		"Buff" => "f0dc82",
		"Bulgarian Rose" => "482427",
		"Bull Shot" => "75442b",
		"Bunker" => "292c2f",
		"Bunting" => "2b3449",
		"Burgundy" => "800020",
		"Burly Wood" => "deb887",
		"Burnham" => "234537",
		"Burning Sand" => "d08363",
		"Burnt Crimson" => "582124",
		"Burnt Orange" => "ff7034",
		"Burnt Sienna" => "e97451",
		"Burnt Umber" => "8a3324",
		"Buttercup" => "da9429",
		"Buttered Rum" => "9d702e",
		"Butterfly Bush" => "68578c",
		"Buttermilk" => "f6e0a4",
		"Buttery White" => "f1ebda",
		"Cab Sav" => "4a2e32",
		"Cabaret" => "cd526c",
		"Cabbage Pont" => "4c5544",
		"Cactus" => "5b6f55",
		"Cadet Blue" => "5f9ea0",
		"Cadillac" => "984961",
		"Cafe Royale" => "6a4928",
		"Calico" => "d5b185",
		"California" => "e98c3a",
		"Calypso" => "3d7188",
		"Camarone" => "206937",
		"Camelot" => "803a4b",
		"Cameo" => "cca483",
		"Camouflage" => "4f4d32",
		"Camouflage Green" => "78866b",
		"Can Can" => "d08a9b",
		"Canary" => "ffff99",
		"Cannon Pink" => "8e5164",
		"Cape Cod" => "4e5552",
		"Cape Honey" => "fee0a5",
		"Cape Palliser" => "75482f",
		"Caper" => "afc182",
		"Caput Mortuum" => "592720",
		"Caramel" => "ffd59a",
		"Cararra" => "ebe5d5",
		"Cardin Green" => "1b3427",
		"Cardinal" => "c41e3a",
		"Careys Pink" => "c99aa0",
		"Caribbean Green" => "00cc99",
		"Carissma" => "e68095",
		"Carla" => "f5f9cb",
		"Carmine" => "960018",
		"Carnaby Tan" => "5b3a24",
		"Carnation Pink" => "ffa6c9",
		"Carousel Pink" => "f8dbe0",
		"Carrot Orange" => "ed9121",
		"Casablanca" => "f0b253",
		"Casal" => "3f545a",
		"Cascade" => "8ca8a0",
		"Cashmere" => "d1b399",
		"Casper" => "aab5b8",
		"Castro" => "44232f",
		"Catalina Blue" => "273c5a",
		"Catskill White" => "e0e4dc",
		"Cavern Pink" => "e0b8b1",
		"Ce Soir" => "9271a7",
		"Cedar" => "463430",
		"Celadon" => "ace1af",
		"Celery" => "b4c04c",
		"Celeste" => "d2d2c0",
		"Cello" => "3a4e5f",
		"Celtic" => "2b3f36",
		"Cement" => "857158",
		"Cerise" => "de3163",
		"Cerulean" => "007ba7",
		"Cerulean Blue" => "2a52be",
		"Chablis" => "fde9e0",
		"Chalet Green" => "5a6e41",
		"Chalky" => "dfc281",
		"Chambray" => "475877",
		"Chamois" => "e8cd9a",
		"Champagne" => "eed9b6",
		"Chantilly" => "edb8c7",
		"Charade" => "394043",
		"Charcoal" => "464646",
		"Chardon" => "f8eadf",
		"Chardonnay" => "ffc878",
		"Charlotte" => "a4dce6",
		"Charm" => "d0748b",
		"Chartreuse" => "7fff00",
		"Chartreuse Yellow" => "dfff00",
		"Chateau Green" => "419f59",
		"Chatelle" => "b3abb6",
		"Chathams Blue" => "2c5971",
		"Chelsea Cucumber" => "88a95b",
		"Chelsea Gem" => "95532f",
		"Chenin" => "dec371",
		"Cherokee" => "f5cd82",
		"Cherry Pie" => "372d52",
		"Cherub" => "f5d7dc",
		"Chestnut" => "b94e48",
		"Chetwode Blue" => "666fb4",
		"Chicago" => "5b5d56",
		"Chiffon" => "f0f5bb",
		"Chilean Fire" => "d05e34",
		"Chilean Heath" => "f9f7de",
		"China Ivory" => "fbf3d3",
		"Chino" => "b8ad8a",
		"Chinook" => "9dd3a8",
		"Chocolate" => "d2691e",
		"Christalle" => "382161",
		"Christi" => "71a91d",
		"Christine" => "bf652e",
		"Chrome White" => "cac7b7",
		"Cigar" => "7d4e38",
		"Cinder" => "242a2e",
		"Cinderella" => "fbd7cc",
		"Cinnabar" => "e34234",
		"Cioccolato" => "5d3b2e",
		"Citron" => "8e9a21",
		"Citrus" => "9fb70a",
		"Clam Shell" => "d2b3a9",
		"Claret" => "6e2233",
		"Classic Rose" => "f4c8db",
		"Clay Creek" => "897e59",
		"Clear Day" => "dfefea",
		"Clinker" => "463623",
		"Cloud" => "c2bcb1",
		"Cloud Burst" => "353e4f",
		"Cloudy" => "b0a99f",
		"Clover" => "47562f",
		"Cobalt" => "0047ab",
		"Cocoa Bean" => "4f3835",
		"Cocoa Brown" => "35281e",
		"Coconut Cream" => "e1dabb",
		"Cod Grey" => "2d3032",
		"Coffee" => "726751",
		"Coffee Bean" => "362d26",
		"Cognac" => "9a463d",
		"Cola" => "3c2f23",
		"Cold Purple" => "9d8abf",
		"Cold Turkey" => "cab5b2",
		"Columbia Blue" => "9bddff",
		"Comet" => "636373",
		"Como" => "4c785c",
		"Conch" => "a0b1ae",
		"Concord" => "827f79",
		"Concrete" => "d2d1cd",
		"Confetti" => "ddcb46",
		"Congo Brown" => "654d49",
		"Conifer" => "b1dd52",
		"Contessa" => "c16f68",
		"Copper" => "da8a67",
		"Copper Canyon" => "77422c",
		"Copper Rose" => "996666",
		"Copper Rust" => "95524c",
		"Coral" => "ff7f50",
		"Coral Candy" => "f5d0c9",
		"Coral Red" => "ff4040",
		"Coral Tree" => "ab6e67",
		"Corduroy" => "404d49",
		"Coriander" => "bbb58d",
		"Cork" => "5a4c42",
		"Corn" => "fbec5d",
		"Corn Field" => "f8f3c4",
		"Corn Flower Blue" => "42426f",
		"Corn Harvest" => "8d702a",
		"Corn Silk" => "fff8dc",
		"Cornflower" => "93ccea",
		"Cornflower Blue" => "6495ed",
		"Corvette" => "e9ba81",
		"Cosmic" => "794d60",
		"Cosmic Latte" => "e1f8e7",
		"Cosmos" => "fcd5cf",
		"Costa Del Sol" => "625d2a",
		"Cotton Candy" => "ffb7d5",
		"Cotton Seed" => "bfbaaf",
		"County Green" => "1b4b35",
		"Cowboy" => "443736",
		"Crab Apple" => "87382f",
		"Crail" => "a65648",
		"Cranberry" => "db5079",
		"Crater Brown" => "4d3e3c",
		"Cream" => "fffdd0",
		"Cream Brulee" => "ffe39b",
		"Cream Can" => "eec051",
		"Creole" => "393227",
		"Crete" => "77712b",
		"Crimson" => "dc143c",
		"Crocodile" => "706950",
		"Crown Of Thorns" => "763c33",
		"Cruise" => "b4e2d5",
		"Crusoe" => "165b31",
		"Crusta" => "f38653",
		"Cumin" => "784430",
		"Cumulus" => "f5f4c1",
		"Cupid" => "f5b2c5",
		"Curious Blue" => "3d85b8",
		"Cutty Sark" => "5c8173",
		"Cyprus" => "0f4645",
		"Dairy Cream" => "edd2a4",
		"Daisy Bush" => "5b3e90",
		"Dallas" => "664a2d",
		"Dandelion" => "fed85d",
		"Danube" => "5b89c0",
		"Dark Blue" => "00008b",
		"Dark Brown" => "654321",
		"Dark Cerulean" => "08457e",
		"Dark Chestnut" => "986960",
		"Dark Coral" => "cd5b45",
		"Dark Cyan" => "008b8b",
		"Dark Goldenrod" => "b8860b",
		"Dark Gray" => "a9a9a9",
		"Dark Green" => "013220",
		"Dark Green Copper" => "4a766e",
		"Dark Khaki" => "bdb76b",
		"Dark Magenta" => "8b008b",
		"Dark Olive Green" => "556b2f",
		"Dark Orange" => "ff8c00",
		"Dark Orchid" => "9932cc",
		"Dark Pastel Green" => "03c03c",
		"Dark Pink" => "e75480",
		"Dark Purple" => "871f78",
		"Dark Red" => "8b0000",
		"Dark Rum" => "45362b",
		"Dark Salmon" => "e9967a",
		"Dark Sea Green" => "8fbc8f",
		"Dark Slate" => "465352",
		"Dark Slate Blue" => "483d8b",
		"Dark Slate Grey" => "2f4f4f",
		"Dark Spring Green" => "177245",
		"Dark Tan" => "97694f",
		"Dark Tangerine" => "ffa812",
		"Dark Turquoise" => "00ced1",
		"Dark Violet" => "9400d3",
		"Dark Wood" => "855e42",
		"Davy's Grey" => "788878",
		"Dawn" => "9f9d91",
		"Dawn Pink" => "e6d6cd",
		"De York" => "85ca87",
		"Deco" => "cccf82",
		"Deep Blush" => "e36f8a",
		"Deep Bronze" => "51412d",
		"Deep Cerise" => "da3287",
		"Deep Fir" => "193925",
		"Deep Koamaru" => "343467",
		"Deep Lilac" => "9955bb",
		"Deep Magenta" => "cc00cc",
		"Deep Pink" => "ff1493",
		"Deep Sea" => "167e65",
		"Deep Sky Blue" => "00bfff",
		"Deep Teal" => "19443c",
		"Del Rio" => "b5998e",
		"Dell" => "486531",
		"Delta" => "999b95",
		"Deluge" => "8272a4",
		"Denim" => "1560bd",
		"Derby" => "f9e4c6",
		"Desert" => "a15f3b",
		"Desert Sand" => "edc9af",
		"Desert Storm" => "ede7e0",
		"Dew" => "e7f2e9",
		"Diesel" => "322c2b",
		"Dim Gray" => "696969",
		"Dingley" => "607c47",
		"Disco" => "892d4f",
		"Dixie" => "cd8431",
		"Dodger Blue" => "1e90ff",
		"Dolly" => "f5f171",
		"Dolphin" => "6a6873",
		"Domino" => "6c5b4c",
		"Don Juan" => "5a4f51",
		"Donkey Brown" => "816e5c",
		"Dorado" => "6e5f56",
		"Double Colonial White" => "e4cf99",
		"Double Pearl Lusta" => "e9dcbe",
		"Double Spanish White" => "d2c3a3",
		"Dove Grey" => "777672",
		"Downy" => "6fd2be",
		"Drover" => "fbeb9b",
		"Dune" => "514f4a",
		"Dust Storm" => "e5cac0",
		"Dusty Grey" => "ac9b9b",
		"Dutch White" => "f0dfbb",
		"Eagle" => "b0ac94",
		"Earls Green" => "b8a722",
		"Early Dawn" => "fbf2db",
		"East Bay" => "47526e",
		"East Side" => "aa8cbc",
		"Eastern Blue" => "00879f",
		"Ebb" => "e6d8d4",
		"Ebony" => "313337",
		"Ebony Clay" => "323438",
		"Echo Blue" => "a4afcd",
		"Eclipse" => "3f3939",
		"Ecru" => "c2b280",
		"Ecru White" => "d6d1c0",
		"Ecstasy" => "c96138",
		"Eden" => "266255",
		"Edgewater" => "c1d8c5",
		"Edward" => "97a49a",
		"Egg Sour" => "f9e4c5",
		"Eggplant" => "990066",
		"Egyptian Blue" => "1034a6",
		"El Paso" => "39392c",
		"El Salva" => "8f4e45",
		"Electric Blue" => "7df9ff",
		"Electric Indigo" => "6600ff",
		"Electric Lime" => "ccff00",
		"Electric Purple" => "bf00ff",
		"Elephant" => "243640",
		"Elf Green" => "1b8a6b",
		"Elm" => "297b76",
		"Emerald" => "50c878",
		"Eminence" => "6e3974",
		"Emperor" => "50494a",
		"Empress" => "7c7173",
		"Endeavour" => "29598b",
		"Energy Yellow" => "f5d752",
		"English Holly" => "274234",
		"Envy" => "8ba58f",
		"Equator" => "dab160",
		"Espresso" => "4e312d",
		"Eternity" => "2d2f28",
		"Eucalyptus" => "329760",
		"Eunry" => "cda59c",
		"Evening Sea" => "26604f",
		"Everglade" => "264334",
		"Fair Pink" => "f3e5dc",
		"Falcon" => "6e5a5b",
		"Fallow" => "c19a6b",
		"Falu Red" => "801818",
		"Fantasy" => "f2e6dd",
		"Fedora" => "625665",
		"Feijoa" => "a5d785",
		"Feldgrau" => "4d5d53",
		"Feldspar" => "d19275",
		"Fern" => "63b76c",
		"Fern Green" => "4f7942",
		"Ferra" => "876a68",
		"Festival" => "eacc4a",
		"Feta" => "dbe0d0",
		"Fiery Orange" => "b1592f",
		"Fiji Green" => "636f22",
		"Finch" => "75785a",
		"Finlandia" => "61755b",
		"Finn" => "694554",
		"Fiord" => "4b5a62",
		"Fire" => "8f3f2a",
		"Fire Brick" => "b22222",
		"Fire Bush" => "e09842",
		"Fire Engine Red" => "ce1620",
		"Firefly" => "314643",
		"Flame Pea" => "be5c48",
		"Flame Red" => "86282e",
		"Flamenco" => "ea8645",
		"Flamingo" => "e1634f",
		"Flax" => "eedc82",
		"Flint" => "716e61",
		"Flirt" => "7a2e4d",
		"Floral White" => "fffaf0",
		"Foam" => "d0eae8",
		"Fog" => "d5c7e8",
		"Foggy Grey" => "a7a69d",
		"Forest Green" => "228b22",
		"Forget Me Not" => "fdefdb",
		"Fountain Blue" => "65adb2",
		"Frangipani" => "ffd7a0",
		"Free Speech Aquamarine" => "029d74",
		"Free Speech Blue" => "4156c5",
		"Free Speech Green" => "09f911",
		"Free Speech Magenta" => "e35bd8",
		"Free Speech Red" => "c00000",
		"French Grey" => "bfbdc1",
		"French Lilac" => "deb7d9",
		"French Pass" => "a4d2e0",
		"French Rose" => "f64a8a",
		"Friar Grey" => "86837a",
		"Fringy Flower" => "b4e1bb",
		"Froly" => "e56d75",
		"Frost" => "e1e4c5",
		"Frosted Mint" => "e2f2e4",
		"Frostee" => "dbe5d2",
		"Fruit Salad" => "4ba351",
		"Fuchsia" => "c154c1",
		"Fuchsia Pink" => "ff77ff",
		"Fuego" => "c2d62e",
		"Fuel Yellow" => "d19033",
		"Fun Blue" => "335083",
		"Fun Green" => "15633d",
		"Fuscous Grey" => "3c3b3c",
		"Fuzzy Wuzzy Brown" => "c45655",
		"Gable Green" => "2c4641",
		"Gainsboro" => "dcdcdc",
		"Gallery" => "dcd7d1",
		"Galliano" => "d8a723",
		"Gamboge" => "e49b0f",
		"Geebung" => "c5832e",
		"Genoa" => "31796d",
		"Geraldine" => "e77b75",
		"Geyser" => "cbd0cf",
		"Ghost" => "c0bfc7",
		"Ghost White" => "f8f8ff",
		"Gigas" => "564786",
		"Gimblet" => "b9ad61",
		"Gin" => "d9dfcd",
		"Gin Fizz" => "f8eaca",
		"Givry" => "ebd4ae",
		"Glacier" => "78b1bf",
		"Glade Green" => "5f8151",
		"Go Ben" => "786e4c",
		"Goblin" => "34533d",
		"Gold" => "ffd700",
		"Gold Drop" => "d56c30",
		"Gold Tips" => "e2b227",
		"Golden Bell" => "ca8136",
		"Golden Brown" => "996515",
		"Golden Dream" => "f1cc2b",
		"Golden Fizz" => "ebde31",
		"Golden Glow" => "f9d77e",
		"Golden Poppy" => "fcc200",
		"Golden Sand" => "eace6a",
		"Golden Tainoi" => "ffc152",
		"Golden Yellow" => "ffdf00",
		"Goldenrod" => "dbdb70",
		"Gondola" => "373332",
		"Gordons Green" => "29332b",
		"Gorse" => "fde336",
		"Gossamer" => "399f86",
		"Gossip" => "9fd385",
		"Gothic" => "698890",
		"Governor Bay" => "51559b",
		"Grain Brown" => "cab8a2",
		"Grandis" => "ffcd73",
		"Granite Green" => "8b8265",
		"Granny Apple" => "c5e7cd",
		"Granny Smith" => "7b948c",
		"Granny Smith Apple" => "9de093",
		"Grape" => "413d4b",
		"Graphite" => "383428",
		"Gravel" => "4a4b46",
		"Green" => "008000",
		"Green House" => "3e6334",
		"Green Kelp" => "393d2a",
		"Green Leaf" => "526b2d",
		"Green Mist" => "bfc298",
		"Green Pea" => "266242",
		"Green Smoke" => "9ca664",
		"Green Spring" => "a9af99",
		"Green Vogue" => "23414e",
		"Green Waterloo" => "2c2d24",
		"Green White" => "deddcb",
		"Green Yellow" => "adff2f",
		"Grenadier" => "c14d36",
		"Grey" => "808080",
		"Grey Chateau" => "9fa3a7",
		"Grey Nickel" => "bdbaae",
		"Grey Nurse" => "d1d3cc",
		"Grey Olive" => "a19a7f",
		"Grey Suit" => "9391a0",
		"Grey-Asparagus" => "465945",
		"Guardsman Red" => "952e31",
		"Gulf Blue" => "343f5c",
		"Gulf Stream" => "74b2a8",
		"Gull Grey" => "a4adb0",
		"Gum Leaf" => "acc9b2",
		"Gumbo" => "718f8a",
		"Gun Powder" => "484753",
		"Gunmetal" => "2c3539",
		"Gunsmoke" => "7a7c76",
		"Gurkha" => "989171",
		"Hacienda" => "9e8022",
		"Hairy Heath" => "633528",
		"Haiti" => "2c2a35",
		"Half And Half" => "ede7c8",
		"Half Baked" => "558f93",
		"Half Colonial White" => "f2e5bf",
		"Half Dutch White" => "fbf0d6",
		"Half Pearl Lusta" => "f1ead7",
		"Half Spanish White" => "e6dbc7",
		"Hampton" => "e8d4a2",
		"Han Purple" => "5218fa",
		"Harlequin" => "3fff00",
		"Harley Davidson Orange" => "c93413",
		"Harp" => "cbcec0",
		"Harvest Gold" => "eab76a",
		"Havana" => "3b2b2c",
		"Havelock Blue" => "5784c1",
		"Hawaiian Tan" => "99522b",
		"Hawkes Blue" => "d2daed",
		"Heath" => "4f2a2c",
		"Heather" => "aebbc1",
		"Heathered Grey" => "948c7e",
		"Heavy Metal" => "46473e",
		"Heliotrope" => "df73ff",
		"Hemlock" => "69684b",
		"Hemp" => "987d73",
		"Highball" => "928c3c",
		"Highland" => "7a9461",
		"Hillary" => "a7a07e",
		"Himalaya" => "736330",
		"Hint Of Green" => "dff1d6",
		"Hint Of Red" => "f5efeb",
		"Hint Of Yellow" => "f6f5d7",
		"Hippie Blue" => "49889a",
		"Hippie Green" => "608a5a",
		"Hippie Pink" => "ab495c",
		"Hit Grey" => "a1a9a8",
		"Hit Pink" => "fda470",
		"Hokey Pokey" => "bb8e34",
		"Hoki" => "647d86",
		"Holly" => "25342b",
		"Hollywood Cerise" => "f400a1",
		"Honey Flower" => "5c3c6d",
		"Honeydew" => "f0fff0",
		"Honeysuckle" => "e8ed69",
		"Hopbush" => "cd6d93",
		"Horizon" => "648894",
		"Horses Neck" => "6d562c",
		"Hot Curry" => "815b28",
		"Hot Magenta" => "ff00cc",
		"Hot Pink" => "ff69b4",
		"Hot Purple" => "4e2e53",
		"Hot Toddy" => "a7752c",
		"Humming Bird" => "ceefe4",
		"Hunter Green" => "355e3b",
		"Hurricane" => "8b7e77",
		"Husk" => "b2994b",
		"Ice Cold" => "afe3d6",
		"Iceberg" => "cae1d9",
		"Illusion" => "ef95ae",
		"Inch Worm" => "b0e313",
		"Indian Red" => "cd5c5c",
		"Indian Tan" => "4f301f",
		"Indigo" => "4b0082",
		"Indochine" => "9c5b34",
		"International Klein Blue" => "002fa7",
		"International Orange" => "ff4f00",
		"Iris Blue" => "03b4c8",
		"Irish Coffee" => "62422b",
		"Iron" => "cbcdcd",
		"Ironside Grey" => "706e66",
		"Ironstone" => "865040",
		"Islamic Green" => "009900",
		"Island Spice" => "f8eddb",
		"Ivory" => "fffff0",
		"Jacarta" => "3d325d",
		"Jacko Bean" => "413628",
		"Jacksons Purple" => "3d3f7d",
		"Jade" => "00a86b",
		"Jaffa" => "e27945",
		"Jagged Ice" => "cae7e2",
		"Jagger" => "3f2e4c",
		"Jaguar" => "29292f",
		"Jambalaya" => "674834",
		"Japanese Laurel" => "2f7532",
		"Japonica" => "ce7259",
		"Java" => "259797",
		"Jazz" => "5f2c2f",
		"Jazzberry Jam" => "a50b5e",
		"Jelly Bean" => "44798e",
		"Jet Stream" => "bbd0c9",
		"Jewel" => "136843",
		"Jon" => "463d3e",
		"Jonquil" => "eef293",
		"Jordy Blue" => "7aaae0",
		"Judge Grey" => "5d5346",
		"Jumbo" => "878785",
		"Jungle Green" => "29ab87",
		"Jungle Mist" => "b0c4c4",
		"Juniper" => "74918e",
		"Just Right" => "dcbfac",
		"Kabul" => "6c5e53",
		"Kaitoke Green" => "245336",
		"Kangaroo" => "c5c3b0",
		"Karaka" => "2d2d24",
		"Karry" => "fedcc1",
		"Kashmir Blue" => "576d8e",
		"Kelly Green" => "4cbb17",
		"Kelp" => "4d503c",
		"Kenyan Copper" => "6c322e",
		"Keppel" => "5fb69c",
		"Khaki" => "f0e68c",
		"Kidnapper" => "bfc0ab",
		"Kilamanjaro" => "3a3532",
		"Killarney" => "49764f",
		"Kimberly" => "695d87",
		"Kingfisher Daisy" => "583580",
		"Kobi" => "e093ab",
		"Kokoda" => "7b785a",
		"Korma" => "804e2c",
		"Koromiko" => "feb552",
		"Kournikova" => "f9d054",
		"La Palma" => "428929",
		"La Rioja" => "bac00e",
		"Las Palmas" => "c6da36",
		"Laser" => "c6a95e",
		"Laser Lemon" => "ffff66",
		"Laurel" => "6e8d71",
		"Lavender" => "e6e6fa",
		"Lavender Blue" => "ccccff",
		"Lavender Blush" => "fff0f5",
		"Lavender Grey" => "bdbbd7",
		"Lavender Pink" => "fbaed2",
		"Lavender Rose" => "fba0e3",
		"Lawn Green" => "7cfc00",
		"Leather" => "906a54",
		"Lemon" => "fde910",
		"Lemon Chiffon" => "fffacd",
		"Lemon Ginger" => "968428",
		"Lemon Grass" => "999a86",
		"Licorice" => "2e3749",
		"Light Blue" => "add8e6",
		"Light Coral" => "f08080",
		"Light Cyan" => "e0ffff",
		"Light Goldenrod" => "eedd82",
		"Light Goldenrod Yellow" => "fafad2",
		"Light Green" => "90ee90",
		"Light Grey" => "d3d3d3",
		"Light Pink" => "ffb6c1",
		"Light Salmon" => "ffa07a",
		"Light Sea Green" => "20b2aa",
		"Light Sky Blue" => "87cefa",
		"Light Slate Blue" => "8470ff",
		"Light Slate Grey" => "778899",
		"Light Steel Blue" => "b0c4de",
		"Light Wood" => "856363",
		"Light Yellow" => "ffffe0",
		"Lightning Yellow" => "f7a233",
		"Lilac" => "c8a2c8",
		"Lilac Bush" => "9470c4",
		"Lily" => "c19fb3",
		"Lily White" => "e9eeeb",
		"Lima" => "7aac21",
		"Lime" => "00ff00",
		"Lime Green" => "32cd32",
		"Limeade" => "5f9727",
		"Limerick" => "89ac27",
		"Linen" => "faf0e6",
		"Link Water" => "c7cdd8",
		"Lipstick" => "962c54",
		"Liver" => "534b4f",
		"Livid Brown" => "312a29",
		"Loafer" => "dbd9c2",
		"Loblolly" => "b3bbb7",
		"Lochinvar" => "489084",
		"Lochmara" => "316ea0",
		"Locust" => "a2a580",
		"Log Cabin" => "393e2e",
		"Logan" => "9d9cb4",
		"Lola" => "b9acbb",
		"London Hue" => "ae94ab",
		"Lonestar" => "522426",
		"Lotus" => "8b504b",
		"Loulou" => "4c3347",
		"Lucky" => "ab9a1c",
		"Lucky Point" => "292d4f",
		"Lunar Green" => "4e5541",
		"Lusty" => "782e2c",
		"Luxor Gold" => "ab8d3f",
		"Lynch" => "697d89",
		"Mabel" => "cbe8e8",
		"Macaroni And Cheese" => "ffb97b",
		"Madang" => "b7e3a8",
		"Madison" => "2d3c54",
		"Madras" => "473e23",
		"Magenta" => "ff00ff",
		"Magic Mint" => "aaf0d1",
		"Magnolia" => "f8f4ff",
		"Mahogany" => "ca3435",
		"Mai Tai" => "a56531",
		"Maire" => "2a2922",
		"Maize" => "e3b982",
		"Makara" => "695f50",
		"Mako" => "505555",
		"Malachite" => "0bda51",
		"Malachite Green" => "97976f",
		"Malibu" => "66b7e1",
		"Mallard" => "3a4531",
		"Malta" => "a59784",
		"Mamba" => "766d7c",
		"Manatee" => "8d90a1",
		"Mandalay" => "b57b2e",
		"Mandarian Orange" => "8e2323",
		"Mandy" => "cd525b",
		"Mandys Pink" => "f5b799",
		"Mango Tango" => "e77200",
		"Manhattan" => "e2af80",
		"Mantis" => "7fc15c",
		"Mantle" => "96a793",
		"Manz" => "e4db55",
		"Mardi Gras" => "352235",
		"Marigold" => "b88a3d",
		"Mariner" => "42639f",
		"Maroon" => "800000",
		"Marshland" => "2b2e26",
		"Martini" => "b7a8a3",
		"Martinique" => "3c3748",
		"Marzipan" => "ebc881",
		"Masala" => "57534b",
		"Matisse" => "365c7d",
		"Matrix" => "8e4d45",
		"Matterhorn" => "524b4b",
		"Mauve" => "e0b0ff",
		"Mauve Taupe" => "915f6d",
		"Mauvelous" => "f091a9",
		"Maverick" => "c8b1c0",
		"Maya Blue" => "73c2fb",
		"McKenzie" => "8c6338",
		"Medium Aquamarine" => "66cdaa",
		"Medium Blue" => "0000cd",
		"Medium Carmine" => "af4035",
		"Medium Goldenrod" => "eaeaae",
		"Medium Orchid" => "ba55d3",
		"Medium Purple" => "9370db",
		"Medium Sea Green" => "3cb371",
		"Medium Slate Blue" => "7b68ee",
		"Medium Spring Green" => "00fa9a",
		"Medium Turquoise" => "48d1cc",
		"Medium Violet Red" => "c71585",
		"Medium Wood" => "a68064",
		"Melanie" => "e0b7c2",
		"Melanzane" => "342931",
		"Melon" => "febaad",
		"Melrose" => "c3b9dd",
		"Mercury" => "d5d2d1",
		"Merino" => "e1dbd0",
		"Merlin" => "4f4e48",
		"Merlot" => "73343a",
		"Metallic Bronze" => "554a3c",
		"Metallic Copper" => "6e3d34",
		"Metallic Gold" => "d4af37",
		"Meteor" => "bb7431",
		"Meteorite" => "4a3b6a",
		"Mexican Red" => "9b3d3d",
		"Mid Grey" => "666a6d",
		"Midnight" => "21303e",
		"Midnight Blue" => "191970",
		"Midnight Express" => "21263a",
		"Midnight Moss" => "242e28",
		"Mikado" => "3f3623",
		"Milan" => "f6f493",
		"Milano Red" => "9e3332",
		"Milk Punch" => "f3e5c0",
		"Milk White" => "dcd9cd",
		"Millbrook" => "595648",
		"Mimosa" => "f5f5cc",
		"Mindaro" => "daea6f",
		"Mine Shaft" => "373e41",
		"Mineral Green" => "506355",
		"Ming" => "407577",
		"Minsk" => "3e3267",
		"Mint Cream" => "f5fffa",
		"Mint Green" => "98ff98",
		"Mint Julep" => "e0d8a7",
		"Mint Tulip" => "c6eadd",
		"Mirage" => "373f43",
		"Mischka" => "a5a9b2",
		"Mist Grey" => "bab9a9",
		"Misty Rose" => "ffe4e1",
		"Mobster" => "605a67",
		"Moccaccino" => "582f2b",
		"Moccasin" => "ffe4b5",
		"Mocha" => "6f372d",
		"Mojo" => "97463c",
		"Mona Lisa" => "ff9889",
		"Monarch" => "6b252c",
		"Mondo" => "554d42",
		"Mongoose" => "a58b6f",
		"Monsoon" => "7a7679",
		"Montana" => "393b3c",
		"Monte Carlo" => "7ac5b4",
		"Moody Blue" => "8378c7",
		"Moon Glow" => "f5f3ce",
		"Moon Mist" => "cecdb8",
		"Moon Raker" => "c0b2d7",
		"Moon Yellow" => "f0c420",
		"Morning Glory" => "9ed1d3",
		"Morocco Brown" => "442d21",
		"Mortar" => "565051",
		"Mosque" => "005f5b",
		"Moss Green" => "addfad",
		"Mountain Meadow" => "1ab385",
		"Mountain Mist" => "a09f9c",
		"Mountbatten Pink" => "997a8d",
		"Muddy Waters" => "a9844f",
		"Muesli" => "9e7e53",
		"Mulberry" => "c54b8c",
		"Mule Fawn" => "884f40",
		"Mulled Wine" => "524d5b",
		"Mustard" => "ffdb58",
		"My Pink" => "d68b80",
		"My Sin" => "fdae45",
		"Myrtle" => "21421e",
		"Mystic" => "d8ddda",
		"Nandor" => "4e5d4e",
		"Napa" => "a39a87",
		"Narvik" => "e9e6dc",
		"Navajo White" => "ffdead",
		"Navy" => "000080",
		"Navy Blue" => "0066cc",
		"Nebula" => "b8c6be",
		"Negroni" => "eec7a2",
		"Neon Blue" => "4d4dff",
		"Neon Carrot" => "ff9933",
		"Neon Pink" => "ff6ec7",
		"Nepal" => "93aab9",
		"Neptune" => "77a8ab",
		"Nero" => "252525",
		"Neutral Green" => "aaa583",
		"Nevada" => "666f6f",
		"New Amber" => "6d3b24",
		"New Midnight Blue" => "00009c",
		"New Orleans" => "e4c385",
		"New Tan" => "ebc79e",
		"New York Pink" => "dd8374",
		"Niagara" => "29a98b",
		"Night Rider" => "332e2e",
		"Night Shadz" => "a23d54",
		"Nile Blue" => "253f4e",
		"Nobel" => "a99d9d",
		"Nomad" => "a19986",
		"Nordic" => "1d393c",
		"Norway" => "a4b88f",
		"Nugget" => "bc9229",
		"Nutmeg" => "7e4a3b",
		"Oasis" => "fcedc5",
		"Observatory" => "008f70",
		"Ocean Green" => "4ca973",
		"Ochre" => "cc7722",
		"Off Green" => "dff0e2",
		"Off Yellow" => "faf3dc",
		"Oil" => "313330",
		"Old Brick" => "8a3335",
		"Old Copper" => "73503b",
		"Old Gold" => "cfb53b",
		"Old Lace" => "fdf5e6",
		"Old Lavender" => "796878",
		"Old Rose" => "c02e4c",
		"Olive" => "808000",
		"Olive Drab" => "6b8e23",
		"Olive Green" => "b5b35c",
		"Olive Haze" => "888064",
		"Olivetone" => "747028",
		"Olivine" => "9ab973",
		"Onahau" => "c2e6ec",
		"Onion" => "48412b",
		"Opal" => "a8c3bc",
		"Opium" => "987e7e",
		"Oracle" => "395555",
		"Orange" => "ffa500",
		"Orange Peel" => "ffa000",
		"Orange Red" => "ff4500",
		"Orange Roughy" => "a85335",
		"Orange White" => "eae3cd",
		"Orchid" => "da70d6",
		"Orchid White" => "f1ebd9",
		"Orient" => "255b77",
		"Oriental Pink" => "c28e88",
		"Orinoco" => "d2d3b3",
		"Oslo Grey" => "818988",
		"Ottoman" => "d3dbcb",
		"Outer Space" => "2d383a",
		"Outrageous Orange" => "ff6037",
		"Oxford Blue" => "28353a",
		"Oxley" => "6d9a78",
		"Oyster Bay" => "d1eaea",
		"Oyster Pink" => "d4b5b0",
		"Paarl" => "864b36",
		"Pablo" => "7a715c",
		"Pacific Blue" => "009dc4",
		"Paco" => "4f4037",
		"Padua" => "7eb394",
		"Palatinate Purple" => "682860",
		"Pale Brown" => "987654",
		"Pale Chestnut" => "ddadaf",
		"Pale Cornflower Blue" => "abcdef",
		"Pale Goldenrod" => "eee8aa",
		"Pale Green" => "98fb98",
		"Pale Leaf" => "bdcaa8",
		"Pale Magenta" => "f984e5",
		"Pale Oyster" => "9c8d72",
		"Pale Pink" => "fadadd",
		"Pale Prim" => "f9f59f",
		"Pale Rose" => "efd6da",
		"Pale Sky" => "636d70",
		"Pale Slate" => "c3bebb",
		"Pale Taupe" => "bc987e",
		"Pale Turquoise" => "afeeee",
		"Pale Violet Red" => "db7093",
		"Palm Green" => "20392c",
		"Palm Leaf" => "36482f",
		"Pampas" => "eae4dc",
		"Panache" => "ebf7e4",
		"Pancho" => "dfb992",
		"Panda" => "544f3a",
		"Papaya Whip" => "ffefd5",
		"Paprika" => "7c2d37",
		"Paradiso" => "488084",
		"Parchment" => "d0c8b0",
		"Paris Daisy" => "fbeb50",
		"Paris M" => "312760",
		"Paris White" => "bfcdc0",
		"Parsley" => "305d35",
		"Pastel Green" => "77dd77",
		"Patina" => "639283",
		"Pattens Blue" => "d3e5ef",
		"Paua" => "2a2551",
		"Pavlova" => "baab87",
		"Payne's Grey" => "404048",
		"Peach" => "ffcba4",
		"Peach Puff" => "ffdab9",
		"Peach-Orange" => "ffcc99",
		"Peach-Yellow" => "fadfad",
		"Peanut" => "7a4434",
		"Pear" => "d1e231",
		"Pearl Bush" => "ded1c6",
		"Pearl Lusta" => "eae0c8",
		"Peat" => "766d52",
		"Pelorous" => "2599b2",
		"Peppermint" => "d7e7d0",
		"Perano" => "acb9e8",
		"Perfume" => "c2a9db",
		"Periglacial Blue" => "acb6b2",
		"Periwinkle" => "c3cde6",
		"Persian Blue" => "1c39bb",
		"Persian Green" => "00a693",
		"Persian Indigo" => "32127a",
		"Persian Pink" => "f77fbe",
		"Persian Plum" => "683332",
		"Persian Red" => "cc3333",
		"Persian Rose" => "fe28a2",
		"Persimmon" => "ec5800",
		"Peru" => "cd853f",
		"Peru Tan" => "733d1f",
		"Pesto" => "7a7229",
		"Petite Orchid" => "da9790",
		"Pewter" => "91a092",
		"Pharlap" => "826663",
		"Picasso" => "f8ea97",
		"Picton Blue" => "5ba0d0",
		"Pig Pink" => "fdd7e4",
		"Pigment Green" => "00a550",
		"Pine Cone" => "756556",
		"Pine Glade" => "bdc07e",
		"Pine Green" => "01796f",
		"Pine Tree" => "2a2f23",
		"Pink" => "ffc0cb",
		"Pink Flamingo" => "ff66ff",
		"Pink Flare" => "d8b4b6",
		"Pink Lace" => "f6ccd7",
		"Pink Lady" => "f3d7b6",
		"Pink Swan" => "bfb3b2",
		"Piper" => "9d5432",
		"Pipi" => "f5e6c4",
		"Pippin" => "fcdbd2",
		"Pirate Gold" => "ba782a",
		"Pixie Green" => "bbcda5",
		"Pizazz" => "e57f3d",
		"Pizza" => "bf8d3c",
		"Plantation" => "3e594c",
		"Plum" => "dda0dd",
		"Pohutukawa" => "651c26",
		"Polar" => "e5f2e7",
		"Polo Blue" => "8aa7cc",
		"Pompadour" => "6a1f44",
		"Porcelain" => "dddcdb",
		"Porsche" => "df9d5b",
		"Port Gore" => "3b436c",
		"Portafino" => "f4f09b",
		"Portage" => "8b98d8",
		"Portica" => "f0d555",
		"Pot Pourri" => "efdcd4",
		"Potters Clay" => "845c40",
		"Powder Blue" => "b0e0e6",
		"Prairie Sand" => "883c32",
		"Prelude" => "cab4d4",
		"Prim" => "e2cdd5",
		"Primrose" => "e4de8e",
		"Promenade" => "f8f6df",
		"Provincial Pink" => "f6e3da",
		"Prussian Blue" => "003366",
		"Psychedelic Purple" => "dd00ff",
		"Puce" => "cc8899",
		"Pueblo" => "6e3326",
		"Puerto Rico" => "59baa3",
		"Pumice" => "bac0b4",
		"Pumpkin" => "ff7518",
		"Punga" => "534931",
		"Purple" => "800080",
		"Purple Heart" => "652dc1",
		"Purple Mountain's Majesty" => "9678b6",
		"Purple Taupe" => "50404d",
		"Putty" => "cdae70",
		"Quarter Pearl Lusta" => "f2eddd",
		"Quarter Spanish White" => "ebe2d2",
		"Quartz" => "d9d9f3",
		"Quicksand" => "c3988b",
		"Quill Grey" => "cbc9c0",
		"Quincy" => "6a5445",
		"Racing Green" => "232f2c",
		"Radical Red" => "ff355e",
		"Raffia" => "dcc6a0",
		"Rain Forest" => "667028",
		"Rainee" => "b3c1b1",
		"Rajah" => "fcae60",
		"Rangoon Green" => "2b2e25",
		"Raven" => "6f747b",
		"Raw Sienna" => "d27d46",
		"Raw Umber" => "734a12",
		"Razzle Dazzle Rose" => "ff33cc",
		"Razzmatazz" => "e30b5c",
		"Rebel" => "453430",
		"Red" => "ff0000",
		"Red Berry" => "701f28",
		"Red Damask" => "cb6f4a",
		"Red Devil" => "662a2c",
		"Red Orange" => "ff3f34",
		"Red Oxide" => "5d1f1e",
		"Red Robin" => "7d4138",
		"Red Stage" => "ad522e",
		"Medium Red Violet" => "bb3385",
		"Redwood" => "5b342e",
		"Reef" => "d1ef9f",
		"Reef Gold" => "a98d36",
		"Regal Blue" => "203f58",
		"Regent Grey" => "798488",
		"Regent St Blue" => "a0cdd9",
		"Remy" => "f6deda",
		"Reno Sand" => "b26e33",
		"Resolution Blue" => "323f75",
		"Revolver" => "37363f",
		"Rhino" => "3d4653",
		"Rice Cake" => "efecde",
		"Rice Flower" => "eff5d1",
		"Rich Blue" => "5959ab",
		"Rich Gold" => "a15226",
		"Rio Grande" => "b7c61a",
		"Riptide" => "89d9c8",
		"River Bed" => "556061",
		"Rob Roy" => "ddad56",
		"Robin's Egg Blue" => "00cccc",
		"Rock" => "5a4d41",
		"Rock Blue" => "93a2ba",
		"Rock Spray" => "9d442d",
		"Rodeo Dust" => "c7a384",
		"Rolling Stone" => "6d7876",
		"Roman" => "d8625b",
		"Roman Coffee" => "7d6757",
		"Romance" => "f4f0e6",
		"Romantic" => "ffc69e",
		"Ronchi" => "eab852",
		"Roof Terracotta" => "a14743",
		"Rope" => "8e593c",
		"Rose" => "d3a194",
		"Rose Bud" => "feab9a",
		"Rose Bud Cherry" => "8a2d52",
		"Rose Of Sharon" => "ac512d",
		"Rose Taupe" => "905d5d",
		"Rose White" => "fbeee8",
		"Rosy Brown" => "bc8f8f",
		"Roti" => "b69642",
		"Rouge" => "a94064",
		"Royal Blue" => "4169e1",
		"Royal Heath" => "b54b73",
		"Royal Purple" => "6b3fa0",
		"Ruby" => "e0115f",
		"Rum" => "716675",
		"Rum Swizzle" => "f1edd4",
		"Russet" => "80461b",
		"Russett" => "7d655c",
		"Rust" => "b7410e",
		"Rustic Red" => "3a181a",
		"Rusty Nail" => "8d5f2c",
		"Saddle" => "5d4e46",
		"Saddle Brown" => "8b4513",
		"Safety Orange" => "ff6600",
		"Saffron" => "f4c430",
		"Sage" => "989f7a",
		"Sahara" => "b79826",
		"Sail" => "a5ceec",
		"Salem" => "177b4d",
		"Salmon" => "fa8072",
		"Salomie" => "ffd67b",
		"Salt Box" => "696268",
		"Saltpan" => "eef3e5",
		"Sambuca" => "3b2e25",
		"San Felix" => "2c6e31",
		"San Juan" => "445761",
		"San Marino" => "4e6c9d",
		"Sand Dune" => "867665",
		"Sandal" => "a3876a",
		"Sandrift" => "af937d",
		"Sandstone" => "786d5f",
		"Sandwisp" => "decb81",
		"Sandy Beach" => "fedbb7",
		"Sandy Brown" => "f4a460",
		"Sangria" => "92000a",
		"Sanguine Brown" => "6c3736",
		"Santas Grey" => "9998a7",
		"Sante Fe" => "a96a50",
		"Sapling" => "e1d5a6",
		"Sapphire" => "082567",
		"Saratoga" => "555b2c",
		"Sauvignon" => "f4eae4",
		"Sazerac" => "f5dec4",
		"Scampi" => "6f63a0",
		"Scandal" => "add9d1",
		"Scarlet" => "ff2400",
		"Scarlet Gum" => "4a2d57",
		"Scarlett" => "7e2530",
		"Scarpa Flow" => "6b6a6c",
		"Schist" => "87876f",
		"School Bus Yellow" => "ffd800",
		"Schooner" => "8d8478",
		"Scooter" => "308ea0",
		"Scorpion" => "6a6466",
		"Scotch Mist" => "eee7c8",
		"Screamin' Green" => "66ff66",
		"Scrub" => "3d4031",
		"Sea Buckthorn" => "ef9548",
		"Sea Fog" => "dfddd6",
		"Sea Green" => "2e8b57",
		"Sea Mist" => "c2d5c4",
		"Sea Nymph" => "8aaea4",
		"Sea Pink" => "db817e",
		"Seagull" => "77b7d0",
		"Seal Brown" => "321414",
		"Seance" => "69326e",
		"Seashell" => "fff5ee",
		"Seaweed" => "37412a",
		"Selago" => "e6dfe7",
		"Selective Yellow" => "ffba00",
		"Semi-Sweet Chocolate" => "6b4226",
		"Sepia" => "9e5b40",
		"Serenade" => "fce9d7",
		"Shadow" => "837050",
		"Shadow Green" => "9ac0b6",
		"Shady Lady" => "9f9b9d",
		"Shakespeare" => "609ab8",
		"Shalimar" => "f8f6a8",
		"Shamrock" => "33cc99",
		"Shamrock Green" => "009e60",
		"Shark" => "34363a",
		"Sherpa Blue" => "00494e",
		"Sherwood Green" => "1b4636",
		"Shilo" => "e6b2a6",
		"Shingle Fawn" => "745937",
		"Ship Cove" => "7988ab",
		"Ship Grey" => "4e4e4c",
		"Shiraz" => "842833",
		"Shocking" => "e899be",
		"Shocking Pink" => "fc0fc0",
		"Shuttle Grey" => "61666b",
		"Siam" => "686b50",
		"Sidecar" => "e9d9a9",
		"Sienna" => "a0522d",
		"Silk" => "bbada1",
		"Silver" => "c0c0c0",
		"Silver Chalice" => "acaea9",
		"Silver Sand" => "bebdb6",
		"Silver Tree" => "67be90",
		"Sinbad" => "a6d5d0",
		"Siren" => "69293b",
		"Sirocco" => "68766e",
		"Sisal" => "c5baa0",
		"Skeptic" => "9db4aa",
		"Sky Blue" => "87ceeb",
		"Slate Blue" => "6a5acd",
		"Slate Grey" => "708090",
		"Slugger" => "42342b",
		"Smalt" => "003399",
		"Smalt Blue" => "496267",
		"Smoke Tree" => "bb5f34",
		"Smoky" => "605d6b",
		"Snow" => "fffafa",
		"Snow Drift" => "e3e3dc",
		"Snow Flurry" => "eaf7c9",
		"Snowy Mint" => "d6f0cd",
		"Snuff" => "e4d7e5",
		"Soapstone" => "ece5da",
		"Soft Amber" => "cfbea5",
		"Soft Peach" => "eedfde",
		"Solid Pink" => "85494c",
		"Solitaire" => "eadac2",
		"Solitude" => "e9ecf1",
		"Sorbus" => "dd6b38",
		"Sorrell Brown" => "9d7f61",
		"Sour Dough" => "c9b59a",
		"Soya Bean" => "6f634b",
		"Space Shuttle" => "4b433b",
		"Spanish Green" => "7b8976",
		"Spanish White" => "ded1b7",
		"Spectra" => "375d4f",
		"Spice" => "6c4f3f",
		"Spicy Mix" => "8b5f4d",
		"Spicy Pink" => "ff1cae",
		"Spindle" => "b3c4d8",
		"Splash" => "f1d79e",
		"Spray" => "7ecddd",
		"Spring Bud" => "a7fc00",
		"Spring Green" => "00ff7f",
		"Spring Rain" => "a3bd9c",
		"Spring Sun" => "f1f1c6",
		"Spring Wood" => "e9e1d9",
		"Sprout" => "b8ca9d",
		"Spun Pearl" => "a2a1ac",
		"Squirrel" => "8f7d6b",
		"St Tropaz" => "325482",
		"Stack" => "858885",
		"Star Dust" => "a0a197",
		"Stark White" => "d2c6b6",
		"Starship" => "e3dd39",
		"Steel Blue" => "4682b4",
		"Steel Grey" => "43464b",
		"Stiletto" => "833d3e",
		"Stonewall" => "807661",
		"Storm Dust" => "65645f",
		"Storm Grey" => "747880",
		"Straw" => "dabe82",
		"Strikemaster" => "946a81",
		"Stromboli" => "406356",
		"Studio" => "724aa1",
		"Submarine" => "8c9c9c",
		"Sugar Cane" => "eeefdf",
		"Sulu" => "c6ea80",
		"Summer Green" => "8fb69c",
		"Summer Sky" => "38b0de",
		"Sun" => "ef8e38",
		"Sundance" => "c4aa4d",
		"Sundown" => "f8afa9",
		"Sunflower" => "dac01a",
		"Sunglo" => "c76155",
		"Sunglow" => "ffcc33",
		"Sunset" => "c0514a",
		"Sunset Orange" => "fe4c40",
		"Sunshade" => "fa9d49",
		"Supernova" => "ffb437",
		"Surf" => "b8d4bb",
		"Surf Crest" => "c3d6bd",
		"Surfie Green" => "007b77",
		"Sushi" => "7c9f2f",
		"Suva Grey" => "8b8685",
		"Swamp" => "252f2f",
		"Swans Down" => "dae6dd",
		"Sweet Corn" => "f9e176",
		"Sweet Pink" => "ee918d",
		"Swirl" => "d7cec5",
		"Swiss Coffee" => "dbd0ca",
		"Tacao" => "f6ae78",
		"Tacha" => "d2b960",
		"Tahiti Gold" => "dc722a",
		"Tahuna Sands" => "d8cc9b",
		"Tall Poppy" => "853534",
		"Tallow" => "a39977",
		"Tamarillo" => "752b2f",
		"Tan" => "d2b48c",
		"Tana" => "b8b5a1",
		"Tangaroa" => "1e2f3c",
		"Tangerine" => "f28500",
		"Tangerine Yellow" => "ffcc00",
		"Tango" => "d46f31",
		"Tapa" => "7c7c72",
		"Tapestry" => "b37084",
		"Tara" => "def1dd",
		"Tarawera" => "253c48",
		"Tasman" => "bac0b3",
		"Taupe" => "483c32",
		"Taupe Grey" => "8b8589",
		"Tawny Port" => "643a48",
		"Tax Break" => "496569",
		"Te Papa Green" => "2b4b40",
		"Tea" => "bfb5a2",
		"Tea Green" => "d0f0c0",
		"Tea Rose" => "f883c2",
		"Teak" => "ab8953",
		"Teal" => "008080",
		"Teal Blue" => "254855",
		"Temptress" => "3c2126",
		"Tenne (Tawny)" => "cd5700",
		"Tequila" => "f4d0a4",
		"Terra Cotta" => "e2725b",
		"Texas" => "ece67e",
		"Texas Rose" => "fcb057",
		"Thatch" => "b1948f",
		"Thatch Green" => "544e31",
		"Thistle" => "d8bfd8",
		"Thunder" => "4d4d4b",
		"Thunderbird" => "923830",
		"Tia Maria" => "97422d",
		"Tiara" => "b9c3be",
		"Tiber" => "184343",
		"Tickle Me Pink" => "fc80a5",
		"Tidal" => "f0f590",
		"Tide" => "beb4ab",
		"Timber Green" => "324336",
		"Timberwolf" => "d9d6cf",
		"Titan White" => "ddd6e1",
		"Toast" => "9f715f",
		"Tobacco Brown" => "6d5843",
		"Tobago" => "44362d",
		"Toledo" => "3e2631",
		"Tolopea" => "2d2541",
		"Tom Thumb" => "4f6348",
		"Tomato" => "ff6347",
		"Tonys Pink" => "e79e88",
		"Topaz" => "817c87",
		"Torch Red" => "fd0e35",
		"Torea Bay" => "353d75",
		"Tory Blue" => "374e88",
		"Tosca" => "744042",
		"Tower Grey" => "9caca5",
		"Tradewind" => "6dafa7",
		"Tranquil" => "ddede9",
		"Travertine" => "e2ddc7",
		"Tree Poppy" => "e2813b",
		"Trendy Green" => "7e8424",
		"Trendy Pink" => "805d80",
		"Trinidad" => "c54f33",
		"Tropical Blue" => "aec9eb",
		"Tropical Rain Forest" => "00755e",
		"Trout" => "4c5356",
		"True V" => "8e72c7",
		"Tuatara" => "454642",
		"Tuft Bush" => "f9d3be",
		"Tulip Tree" => "e3ac3d",
		"Tumbleweed" => "dea681",
		"Tuna" => "46494e",
		"Tundora" => "585452",
		"Turbo" => "f5cc23",
		"Turkish Rose" => "a56e75",
		"Turmeric" => "ae9041",
		"Turquoise" => "40e0d0",
		"Turquoise Blue" => "6cdae7",
		"Turtle Green" => "363e1d",
		"Tuscany" => "ad6242",
		"Tusk" => "e3e5b1",
		"Tussock" => "bf914b",
		"Tutu" => "f8e4e3",
		"Twilight" => "dac0cd",
		"Twilight Blue" => "f4f6ec",
		"Twine" => "c19156",
		"Tyrian Purple" => "66023c",
		"Ultra Pink" => "ff6fff",
		"Ultramarine" => "120a8f",
		"Valencia" => "d4574e",
		"Valentino" => "382c38",
		"Valhalla" => "2a2b41",
		"Van Cleef" => "523936",
		"Vanilla" => "ccb69b",
		"Vanilla Ice" => "ebd2d1",
		"Varden" => "fdefd3",
		"Venetian Red" => "c80815",
		"Venice Blue" => "2c5778",
		"Venus" => "8b7d82",
		"Verdigris" => "62603e",
		"Verdun Green" => "48531a",
		"Vermilion" => "ff4d00",
		"Very Dark Brown" => "5c4033",
		"Very Light Grey" => "cdcdcd",
		"Vesuvius" => "a85533",
		"Victoria" => "564985",
		"Vida Loca" => "5f9228",
		"Viking" => "4db1c8",
		"Vin Rouge" => "955264",
		"Viola" => "c58f9d",
		"Violent Violet" => "2e2249",
		"Violet" => "ee82ee",
		"Violet Blue" => "9f5f9f",
		"Violet Red" => "f7468a",
		"Viridian" => "40826d",
		"Viridian Green" => "4b5f56",
		"Vis Vis" => "f9e496",
		"Vista Blue" => "97d5b3",
		"Vista White" => "e3dfd9",
		"Vivid Tangerine" => "ff9980",
		"Vivid Violet" => "803790",
		"Volcano" => "4e2728",
		"Voodoo" => "443240",
		"Vulcan" => "36383c",
		"Wafer" => "d4bbb1",
		"Waikawa Grey" => "5b6e91",
		"Waiouru" => "4c4e31",
		"Wan White" => "e4e2dc",
		"Wasabi" => "849137",
		"Water Leaf" => "b6ecde",
		"Watercourse" => "006e4e",
		"Wattle" => "d6ca3d",
		"Watusi" => "f2cdbb",
		"Wax Flower" => "eeb39e",
		"We Peep" => "fdd7d8",
		"Wedgewood" => "4c6b88",
		"Well Read" => "8e3537",
		"West Coast" => "5c512f",
		"West Side" => "e5823a",
		"Westar" => "d4cfc5",
		"Wewak" => "f1919a",
		"Wheat" => "f5deb3",
		"Wheatfield" => "dfd7bd",
		"Whiskey" => "d29062",
		"Whiskey Sour" => "d4915d",
		"Whisper" => "efe6e6",
		"White" => "ffffff",
		"White Ice" => "d7eee4",
		"White Lilac" => "e7e5e8",
		"White Linen" => "eee7dc",
		"White Nectar" => "f8f6d8",
		"White Pointer" => "dad6cc",
		"White Rock" => "d4cfb4",
		"White Smoke" => "f5f5f5",
		"Wild Blue Yonder" => "7a89b8",
		"Wild Rice" => "e3d474",
		"Wild Sand" => "e7e4de",
		"Wild Strawberry" => "ff3399",
		"Wild Watermelon" => "fd5b78",
		"Wild Willow" => "beca60",
		"William" => "53736f",
		"Willow Brook" => "dfe6cf",
		"Willow Grove" => "69755c",
		"Windsor" => "462c77",
		"Wine Berry" => "522c35",
		"Winter Hazel" => "d0c383",
		"Wisp Pink" => "f9e8e2",
		"Wisteria" => "c9a0dc",
		"Wistful" => "a29ecd",
		"Witch Haze" => "fbf073",
		"Wood Bark" => "302621",
		"Woodburn" => "463629",
		"Woodland" => "626746",
		"Woodrush" => "45402b",
		"Woodsmoke" => "2b3230",
		"Woody Brown" => "554545",
		"Xanadu" => "75876e",
		"Yellow" => "ffff00",
		"Yellow Green" => "9acd32",
		"Yellow Metal" => "73633e",
		"Yellow Orange" => "ffae42",
		"Yellow Sea" => "f49f35",
		"Your Pink" => "ffc5bb",
		"Yukon Gold" => "826a21",
		"Yuma" => "c7b882",
		"Zambezi" => "6b5a5a",
		"Zanah" => "b2c6b1",
		"Zest" => "c6723b",
		"Zeus" => "3b3c38",
		"Ziggurat" => "81a6aa",
		"Zinnwaldite" => "ebc2af",
		"Zircon" => "dee3e3",
		"Zombie" => "ddc283",
		"Zorba" => "a29589",
		"Zuccini" => "17462e",);

		$main_colors_key = array("Acadia" => "Brown",
		"Acapulco" => "Green",
		"Aero Blue" => "Green",
		"Affair" => "Violet",
		"Afghan Tan" => "Yellow",
		"Air Force Blue" => "Blue",
		"Akaroa" => "Yellow",
		"Alabaster" => "Grey",
		"Albescent White" => "Yellow",
		"Alert Tan" => "Orange",
		"Alice Blue" => "Blue",
		"Alizarin" => "Red",
		"Allports" => "Blue",
		"Almond" => "Yellow",
		"Almond Frost" => "Brown",
		"Alpine" => "Yellow",
		"Alto" => "Grey",
		"Aluminium" => "Grey",
		"Amaranth" => "Red",
		"Amazon" => "Green",
		"Amber" => "Yellow",
		"Americano" => "Brown",
		"Amethyst" => "Violet",
		"Amethyst Smoke" => "Violet",
		"Amour" => "Violet",
		"Amulet" => "Green",
		"Anakiwa" => "Blue",
		"Antique Brass" => "Orange",
		"Antique White" => "White",
		"Anzac" => "Yellow",
		"Apache" => "Yellow",
		"Apple" => "Green",
		"Apple Blossom" => "Red",
		"Apple Green" => "Green",
		"Apricot" => "Orange",
		"Apricot White" => "Yellow",
		"Aqua" => "Blue",
		"Aqua Haze" => "Grey",
		"Aqua Spring" => "Green",
		"Aqua Squeeze" => "Grey",
		"Aquamarine" => "Blue",
		"Arapawa" => "Blue",
		"Armadillo" => "Grey",
		"Army green" => "Green",
		"Arrowtown" => "Yellow",
		"Arsenic" => "Grey",
		"Ash" => "Green",
		"Asparagus" => "Green",
		"Astra" => "Yellow",
		"Astral" => "Blue",
		"Astronaut" => "Blue",
		"Astronaut Blue" => "Blue",
		"Athens Grey" => "Grey",
		"Aths Special" => "Yellow",
		"Atlantis" => "Green",
		"Atoll" => "Green",
		"Atomic" => "Blue",
		"Atomic Tangerine" => "Orange",
		"Au Chico" => "Brown",
		"Aubergine" => "Brown",
		"Auburn" => "Brown",
		"Australian Mint" => "Green",
		"Avocado" => "Green",
		"Axolotl" => "Green",
		"Azalea" => "Red",
		"Aztec" => "Green",
		"Azure" => "Blue",
		"Baby Blue" => "Blue",
		"Bahama Blue" => "Blue",
		"Bahia" => "Green",
		"Baker's Chocolate" => "Brown",
		"Bali Hai" => "Blue",
		"Baltic Sea" => "Grey",
		"Banana Mania" => "Yellow",
		"Bandicoot" => "Green",
		"Barberry" => "Green",
		"Barley Corn" => "Yellow",
		"Barley White" => "Yellow",
		"Barossa" => "Violet",
		"Bastille" => "Blue",
		"Battleship Grey" => "Grey",
		"Bay Leaf" => "Green",
		"Bay Of Many" => "Blue",
		"Bazaar" => "Brown",
		"Beauty Bush" => "Red",
		"Beaver" => "Brown",
		"Beeswax" => "Yellow",
		"Beige" => "Brown",
		"Bermuda" => "Green",
		"Bermuda Grey" => "Blue",
		"Beryl Green" => "Green",
		"Bianca" => "Yellow",
		"Big Stone" => "Blue",
		"Bilbao" => "Green",
		"Biloba Flower" => "Violet",
		"Birch" => "Yellow",
		"Bird Flower" => "Green",
		"Biscay" => "Blue",
		"Bismark" => "Blue",
		"Bison Hide" => "Yellow",
		"Bisque" => "Brown",
		"Bistre" => "Brown",
		"Bitter" => "Green",
		"Bitter Lemon" => "Green",
		"Bittersweet" => "Orange",
		"Bizarre" => "Orange",
		"Black" => "Black",
		"Black Bean" => "Green",
		"Black Forest" => "Green",
		"Black Haze" => "Grey",
		"Black Magic" => "Brown",
		"Black Marlin" => "Blue",
		"Black Pearl" => "Blue",
		"Black Rock" => "Blue",
		"Black Rose" => "Red",
		"Black Russian" => "Grey",
		"Black Squeeze" => "Grey",
		"Black White" => "Grey",
		"Blackberry" => "Violet",
		"Blackcurrant" => "Violet",
		"Blanc" => "Yellow",
		"Blanched Almond" => "Brown",
		"Bleach White" => "Yellow",
		"Blizzard Blue" => "Blue",
		"Blossom" => "Red",
		"Blue" => "Blue",
		"Blue Bayoux" => "Blue",
		"Blue Bell" => "Blue",
		"Blue Chalk" => "Violet",
		"Blue Charcoal" => "Blue",
		"Blue Chill" => "Green",
		"Blue Diamond" => "Violet",
		"Blue Dianne" => "Green",
		"Blue Gem" => "Violet",
		"Blue Haze" => "Violet",
		"Blue Lagoon" => "Green",
		"Blue Marguerite" => "Violet",
		"Blue Romance" => "Green",
		"Blue Smoke" => "Green",
		"Blue Stone" => "Green",
		"Blue Violet" => "Violet",
		"Blue Whale" => "Blue",
		"Blue Zodiac" => "Blue",
		"Blumine" => "Blue",
		"Blush" => "Red",
		"Bokara Grey" => "Grey",
		"Bole" => "Brown",
		"Bombay" => "Grey",
		"Bon Jour" => "Grey",
		"Bondi Blue" => "Blue",
		"Bone" => "Orange",
		"Bordeaux" => "Red",
		"Bossanova" => "Violet",
		"Boston Blue" => "Blue",
		"Botticelli" => "Blue",
		"Bottle Green" => "Green",
		"Boulder" => "Grey",
		"Bouquet" => "Violet",
		"Bourbon" => "Orange",
		"Bracken" => "Brown",
		"Brandy" => "Orange",
		"Brandy Punch" => "Orange",
		"Brandy Rose" => "Red",
		"Brass" => "Yellow",
		"Breaker Bay" => "Green",
		"Brick Red" => "Red",
		"Bridal Heath" => "Orange",
		"Bridesmaid" => "Orange",
		"Bright Green" => "Green",
		"Bright Grey" => "Grey",
		"Bright Red" => "Red",
		"Bright Sun" => "Yellow",
		"Bright Turquoise" => "Blue",
		"Brilliant Rose" => "Red",
		"Brink Pink" => "Pink",
		"British Racing Green" => "Green",
		"Bronco" => "Brown",
		"Bronze" => "Brown",
		"Bronze Olive" => "Yellow",
		"Bronzetone" => "Yellow",
		"Broom" => "Yellow",
		"Brown" => "Brown",
		"Brown Bramble" => "Brown",
		"Brown Derby" => "Brown",
		"Brown Pod" => "Brown",
		"Bubbles" => "Green",
		"Buccaneer" => "Red",
		"Bud" => "Green",
		"Buddha Gold" => "Yellow",
		"Buff" => "Yellow",
		"Bulgarian Rose" => "Red",
		"Bull Shot" => "Orange",
		"Bunker" => "Grey",
		"Bunting" => "Blue",
		"Burgundy" => "Red",
		"Burly Wood" => "Brown",
		"Burnham" => "Green",
		"Burning Sand" => "Orange",
		"Burnt Crimson" => "Red",
		"Burnt Orange" => "Orange",
		"Burnt Sienna" => "Brown",
		"Burnt Umber" => "Brown",
		"Buttercup" => "Yellow",
		"Buttered Rum" => "Yellow",
		"Butterfly Bush" => "Violet",
		"Buttermilk" => "Yellow",
		"Buttery White" => "Yellow",
		"Cab Sav" => "Red",
		"Cabaret" => "Red",
		"Cabbage Pont" => "Green",
		"Cactus" => "Green",
		"Cadet Blue" => "Blue",
		"Cadillac" => "Red",
		"Cafe Royale" => "Brown",
		"Calico" => "Brown",
		"California" => "Orange",
		"Calypso" => "Blue",
		"Camarone" => "Green",
		"Camelot" => "Red",
		"Cameo" => "Brown",
		"Camouflage" => "Yellow",
		"Camouflage Green" => "Green",
		"Can Can" => "Red",
		"Canary" => "Yellow",
		"Cannon Pink" => "Pink",
		"Cape Cod" => "Grey",
		"Cape Honey" => "Yellow",
		"Cape Palliser" => "Orange",
		"Caper" => "Green",
		"Caput Mortuum" => "Brown",
		"Caramel" => "Yellow",
		"Cararra" => "Green",
		"Cardin Green" => "Green",
		"Cardinal" => "Red",
		"Careys Pink" => "Pink",
		"Caribbean Green" => "Green",
		"Carissma" => "Red",
		"Carla" => "Green",
		"Carmine" => "Red",
		"Carnaby Tan" => "Brown",
		"Carnation Pink" => "Pink",
		"Carousel Pink" => "Pink",
		"Carrot Orange" => "Orange",
		"Casablanca" => "Yellow",
		"Casal" => "Blue",
		"Cascade" => "Green",
		"Cashmere" => "Brown",
		"Casper" => "Blue",
		"Castro" => "Red",
		"Catalina Blue" => "Blue",
		"Catskill White" => "Grey",
		"Cavern Pink" => "Pink",
		"Ce Soir" => "Violet",
		"Cedar" => "Brown",
		"Celadon" => "Green",
		"Celery" => "Green",
		"Celeste" => "Green",
		"Cello" => "Blue",
		"Celtic" => "Green",
		"Cement" => "Brown",
		"Cerise" => "Violet",
		"Cerulean" => "Blue",
		"Cerulean Blue" => "Blue",
		"Chablis" => "Red",
		"Chalet Green" => "Green",
		"Chalky" => "Yellow",
		"Chambray" => "Blue",
		"Chamois" => "Yellow",
		"Champagne" => "Yellow",
		"Chantilly" => "Red",
		"Charade" => "Blue",
		"Charcoal" => "Grey",
		"Chardon" => "Orange",
		"Chardonnay" => "Yellow",
		"Charlotte" => "Blue",
		"Charm" => "Red",
		"Chartreuse" => "Green",
		"Chartreuse Yellow" => "Yellow",
		"Chateau Green" => "Green",
		"Chatelle" => "Violet",
		"Chathams Blue" => "Blue",
		"Chelsea Cucumber" => "Green",
		"Chelsea Gem" => "Orange",
		"Chenin" => "Yellow",
		"Cherokee" => "Yellow",
		"Cherry Pie" => "Violet",
		"Cherub" => "Red",
		"Chestnut" => "Brown",
		"Chetwode Blue" => "Blue",
		"Chicago" => "Grey",
		"Chiffon" => "Green",
		"Chilean Fire" => "Orange",
		"Chilean Heath" => "Green",
		"China Ivory" => "Green",
		"Chino" => "Yellow",
		"Chinook" => "Green",
		"Chocolate" => "Brown",
		"Christalle" => "Violet",
		"Christi" => "Green",
		"Christine" => "Orange",
		"Chrome White" => "Green",
		"Cigar" => "Brown",
		"Cinder" => "Grey",
		"Cinderella" => "Red",
		"Cinnabar" => "Red",
		"Cioccolato" => "Brown",
		"Citron" => "Green",
		"Citrus" => "Green",
		"Clam Shell" => "Orange",
		"Claret" => "Red",
		"Classic Rose" => "Violet",
		"Clay Creek" => "Yellow",
		"Clear Day" => "Green",
		"Clinker" => "Brown",
		"Cloud" => "Yellow",
		"Cloud Burst" => "Blue",
		"Cloudy" => "Brown",
		"Clover" => "Green",
		"Cobalt" => "Blue",
		"Cocoa Bean" => "Red",
		"Cocoa Brown" => "Brown",
		"Coconut Cream" => "Green",
		"Cod Grey" => "Grey",
		"Coffee" => "Yellow",
		"Coffee Bean" => "Brown",
		"Cognac" => "Red",
		"Cola" => "Brown",
		"Cold Purple" => "Violet",
		"Cold Turkey" => "Red",
		"Columbia Blue" => "Blue",
		"Comet" => "Blue",
		"Como" => "Green",
		"Conch" => "Green",
		"Concord" => "Grey",
		"Concrete" => "Grey",
		"Confetti" => "Green",
		"Congo Brown" => "Brown",
		"Conifer" => "Green",
		"Contessa" => "Red",
		"Copper" => "Red",
		"Copper Canyon" => "Orange",
		"Copper Rose" => "Violet",
		"Copper Rust" => "Red",
		"Coral" => "Orange",
		"Coral Candy" => "Red",
		"Coral Red" => "Red",
		"Coral Tree" => "Red",
		"Corduroy" => "Green",
		"Coriander" => "Green",
		"Cork" => "Brown",
		"Corn" => "Yellow",
		"Corn Field" => "Green",
		"Corn Flower Blue" => "Blue",
		"Corn Harvest" => "Yellow",
		"Corn Silk" => "Yellow",
		"Cornflower" => "Blue",
		"Cornflower Blue" => "Blue",
		"Corvette" => "Orange",
		"Cosmic" => "Violet",
		"Cosmic Latte" => "White",
		"Cosmos" => "Red",
		"Costa Del Sol" => "Green",
		"Cotton Candy" => "Red",
		"Cotton Seed" => "Yellow",
		"County Green" => "Green",
		"Cowboy" => "Brown",
		"Crab Apple" => "Red",
		"Crail" => "Red",
		"Cranberry" => "Red",
		"Crater Brown" => "Brown",
		"Cream" => "White",
		"Cream Brulee" => "Yellow",
		"Cream Can" => "Yellow",
		"Creole" => "Brown",
		"Crete" => "Green",
		"Crimson" => "Red",
		"Crocodile" => "Yellow",
		"Crown Of Thorns" => "Red",
		"Cruise" => "Green",
		"Crusoe" => "Green",
		"Crusta" => "Orange",
		"Cumin" => "Orange",
		"Cumulus" => "Green",
		"Cupid" => "Red",
		"Curious Blue" => "Blue",
		"Cutty Sark" => "Green",
		"Cyprus" => "Green",
		"Dairy Cream" => "Yellow",
		"Daisy Bush" => "Violet",
		"Dallas" => "Brown",
		"Dandelion" => "Yellow",
		"Danube" => "Blue",
		"Dark Blue" => "Blue",
		"Dark Brown" => "Brown",
		"Dark Cerulean" => "Blue",
		"Dark Chestnut" => "Red",
		"Dark Coral" => "Orange",
		"Dark Cyan" => "Green",
		"Dark Goldenrod" => "Yellow",
		"Dark Gray" => "Grey",
		"Dark Green" => "Green",
		"Dark Green Copper" => "Green",
		"Dark Khaki" => "Yellow",
		"Dark Magenta" => "Violet",
		"Dark Olive Green" => "Green",
		"Dark Orange" => "Orange",
		"Dark Orchid" => "Violet",
		"Dark Pastel Green" => "Green",
		"Dark Pink" => "Pink",
		"Dark Purple" => "Violet",
		"Dark Red" => "Red",
		"Dark Rum" => "Brown",
		"Dark Salmon" => "Orange",
		"Dark Sea Green" => "Green",
		"Dark Slate" => "Green",
		"Dark Slate Blue" => "Blue",
		"Dark Slate Grey" => "Grey",
		"Dark Spring Green" => "Green",
		"Dark Tan" => "Brown",
		"Dark Tangerine" => "Orange",
		"Dark Turquoise" => "Blue",
		"Dark Violet" => "Violet",
		"Dark Wood" => "Brown",
		"Davy's Grey" => "Grey",
		"Dawn" => "Green",
		"Dawn Pink" => "Pink",
		"De York" => "Green",
		"Deco" => "Green",
		"Deep Blush" => "Red",
		"Deep Bronze" => "Brown",
		"Deep Cerise" => "Violet",
		"Deep Fir" => "Green",
		"Deep Koamaru" => "Violet",
		"Deep Lilac" => "Violet",
		"Deep Magenta" => "Violet",
		"Deep Pink" => "Pink",
		"Deep Sea" => "Green",
		"Deep Sky Blue" => "Blue",
		"Deep Teal" => "Green",
		"Del Rio" => "Brown",
		"Dell" => "Green",
		"Delta" => "Grey",
		"Deluge" => "Violet",
		"Denim" => "Blue",
		"Derby" => "Yellow",
		"Desert" => "Orange",
		"Desert Sand" => "Brown",
		"Desert Storm" => "Grey",
		"Dew" => "Green",
		"Diesel" => "Grey",
		"Dim Gray" => "Grey",
		"Dingley" => "Green",
		"Disco" => "Red",
		"Dixie" => "Yellow",
		"Dodger Blue" => "Blue",
		"Dolly" => "Green",
		"Dolphin" => "Violet",
		"Domino" => "Brown",
		"Don Juan" => "Brown",
		"Donkey Brown" => "Brown",
		"Dorado" => "Brown",
		"Double Colonial White" => "Yellow",
		"Double Pearl Lusta" => "Yellow",
		"Double Spanish White" => "Yellow",
		"Dove Grey" => "Grey",
		"Downy" => "Green",
		"Drover" => "Yellow",
		"Dune" => "Grey",
		"Dust Storm" => "Orange",
		"Dusty Grey" => "Grey",
		"Dutch White" => "Yellow",
		"Eagle" => "Green",
		"Earls Green" => "Green",
		"Early Dawn" => "Yellow",
		"East Bay" => "Blue",
		"East Side" => "Violet",
		"Eastern Blue" => "Blue",
		"Ebb" => "Red",
		"Ebony" => "Grey",
		"Ebony Clay" => "Grey",
		"Echo Blue" => "Blue",
		"Eclipse" => "Grey",
		"Ecru" => "Brown",
		"Ecru White" => "Green",
		"Ecstasy" => "Orange",
		"Eden" => "Green",
		"Edgewater" => "Green",
		"Edward" => "Green",
		"Egg Sour" => "Yellow",
		"Eggplant" => "Violet",
		"Egyptian Blue" => "Blue",
		"El Paso" => "Green",
		"El Salva" => "Red",
		"Electric Blue" => "Blue",
		"Electric Indigo" => "Violet",
		"Electric Lime" => "Green",
		"Electric Purple" => "Violet",
		"Elephant" => "Blue",
		"Elf Green" => "Green",
		"Elm" => "Green",
		"Emerald" => "Green",
		"Eminence" => "Violet",
		"Emperor" => "Grey",
		"Empress" => "Grey",
		"Endeavour" => "Blue",
		"Energy Yellow" => "Yellow",
		"English Holly" => "Green",
		"Envy" => "Green",
		"Equator" => "Yellow",
		"Espresso" => "Red",
		"Eternity" => "Green",
		"Eucalyptus" => "Green",
		"Eunry" => "Red",
		"Evening Sea" => "Green",
		"Everglade" => "Green",
		"Fair Pink" => "Pink",
		"Falcon" => "Brown",
		"Fallow" => "Brown",
		"Falu Red" => "Red",
		"Fantasy" => "Orange",
		"Fedora" => "Violet",
		"Feijoa" => "Green",
		"Feldgrau" => "Grey",
		"Feldspar" => "Red",
		"Fern" => "Green",
		"Fern Green" => "Green",
		"Ferra" => "Brown",
		"Festival" => "Yellow",
		"Feta" => "Green",
		"Fiery Orange" => "Orange",
		"Fiji Green" => "Green",
		"Finch" => "Green",
		"Finlandia" => "Green",
		"Finn" => "Violet",
		"Fiord" => "Blue",
		"Fire" => "Orange",
		"Fire Brick" => "Red",
		"Fire Bush" => "Yellow",
		"Fire Engine Red" => "Red",
		"Firefly" => "Green",
		"Flame Pea" => "Orange",
		"Flame Red" => "Red",
		"Flamenco" => "Orange",
		"Flamingo" => "Orange",
		"Flax" => "Yellow",
		"Flint" => "Green",
		"Flirt" => "Red",
		"Floral White" => "White",
		"Foam" => "Green",
		"Fog" => "Violet",
		"Foggy Grey" => "Grey",
		"Forest Green" => "Green",
		"Forget Me Not" => "Yellow",
		"Fountain Blue" => "Blue",
		"Frangipani" => "Yellow",
		"Free Speech Aquamarine" => "Green",
		"Free Speech Blue" => "Blue",
		"Free Speech Green" => "Green",
		"Free Speech Magenta" => "Red",
		"Free Speech Red" => "Red",
		"French Grey" => "Grey",
		"French Lilac" => "Violet",
		"French Pass" => "Blue",
		"French Rose" => "Red",
		"Friar Grey" => "Grey",
		"Fringy Flower" => "Green",
		"Froly" => "Red",
		"Frost" => "Green",
		"Frosted Mint" => "Green",
		"Frostee" => "Green",
		"Fruit Salad" => "Green",
		"Fuchsia" => "Violet",
		"Fuchsia Pink" => "Pink",
		"Fuego" => "Green",
		"Fuel Yellow" => "Yellow",
		"Fun Blue" => "Blue",
		"Fun Green" => "Green",
		"Fuscous Grey" => "Grey",
		"Fuzzy Wuzzy Brown" => "Brown",
		"Gable Green" => "Green",
		"Gainsboro" => "White",
		"Gallery" => "Grey",
		"Galliano" => "Yellow",
		"Gamboge" => "Yellow",
		"Geebung" => "Yellow",
		"Genoa" => "Green",
		"Geraldine" => "Red",
		"Geyser" => "Grey",
		"Ghost" => "Blue",
		"Ghost White" => "White",
		"Gigas" => "Violet",
		"Gimblet" => "Green",
		"Gin" => "Green",
		"Gin Fizz" => "Yellow",
		"Givry" => "Yellow",
		"Glacier" => "Blue",
		"Glade Green" => "Green",
		"Go Ben" => "Yellow",
		"Goblin" => "Green",
		"Gold" => "Yellow",
		"Gold Drop" => "Orange",
		"Gold Tips" => "Yellow",
		"Golden Bell" => "Orange",
		"Golden Brown" => "Brown",
		"Golden Dream" => "Yellow",
		"Golden Fizz" => "Green",
		"Golden Glow" => "Yellow",
		"Golden Poppy" => "Yellow",
		"Golden Sand" => "Yellow",
		"Golden Tainoi" => "Yellow",
		"Golden Yellow" => "Yellow",
		"Goldenrod" => "Yellow",
		"Gondola" => "Grey",
		"Gordons Green" => "Green",
		"Gorse" => "Green",
		"Gossamer" => "Green",
		"Gossip" => "Green",
		"Gothic" => "Blue",
		"Governor Bay" => "Blue",
		"Grain Brown" => "Yellow",
		"Grandis" => "Yellow",
		"Granite Green" => "Yellow",
		"Granny Apple" => "Green",
		"Granny Smith" => "Green",
		"Granny Smith Apple" => "Green",
		"Grape" => "Violet",
		"Graphite" => "Yellow",
		"Gravel" => "Grey",
		"Green" => "Green",
		"Green House" => "Green",
		"Green Kelp" => "Green",
		"Green Leaf" => "Green",
		"Green Mist" => "Green",
		"Green Pea" => "Green",
		"Green Smoke" => "Green",
		"Green Spring" => "Green",
		"Green Vogue" => "Blue",
		"Green Waterloo" => "Green",
		"Green White" => "Green",
		"Green Yellow" => "Green",
		"Grenadier" => "Orange",
		"Grey" => "Grey",
		"Grey Chateau" => "Grey",
		"Grey Nickel" => "Green",
		"Grey Nurse" => "Grey",
		"Grey Olive" => "Yellow",
		"Grey Suit" => "Blue",
		"Grey-Asparagus" => "Green",
		"Guardsman Red" => "Red",
		"Gulf Blue" => "Blue",
		"Gulf Stream" => "Green",
		"Gull Grey" => "Grey",
		"Gum Leaf" => "Green",
		"Gumbo" => "Green",
		"Gun Powder" => "Violet",
		"Gunmetal" => "Blue",
		"Gunsmoke" => "Grey",
		"Gurkha" => "Green",
		"Hacienda" => "Yellow",
		"Hairy Heath" => "Brown",
		"Haiti" => "Violet",
		"Half And Half" => "Green",
		"Half Baked" => "Blue",
		"Half Colonial White" => "Yellow",
		"Half Dutch White" => "Yellow",
		"Half Pearl Lusta" => "Yellow",
		"Half Spanish White" => "Yellow",
		"Hampton" => "Yellow",
		"Han Purple" => "Violet",
		"Harlequin" => "Green",
		"Harley Davidson Orange" => "Orange",
		"Harp" => "Green",
		"Harvest Gold" => "Yellow",
		"Havana" => "Brown",
		"Havelock Blue" => "Blue",
		"Hawaiian Tan" => "Orange",
		"Hawkes Blue" => "Blue",
		"Heath" => "Red",
		"Heather" => "Blue",
		"Heathered Grey" => "Brown",
		"Heavy Metal" => "Grey",
		"Heliotrope" => "Violet",
		"Hemlock" => "Yellow",
		"Hemp" => "Brown",
		"Highball" => "Green",
		"Highland" => "Green",
		"Hillary" => "Green",
		"Himalaya" => "Yellow",
		"Hint Of Green" => "Green",
		"Hint Of Red" => "Grey",
		"Hint Of Yellow" => "Green",
		"Hippie Blue" => "Blue",
		"Hippie Green" => "Green",
		"Hippie Pink" => "Pink",
		"Hit Grey" => "Grey",
		"Hit Pink" => "Pink",
		"Hokey Pokey" => "Yellow",
		"Hoki" => "Blue",
		"Holly" => "Green",
		"Hollywood Cerise" => "Red",
		"Honey Flower" => "Violet",
		"Honeydew" => "White",
		"Honeysuckle" => "Green",
		"Hopbush" => "Violet",
		"Horizon" => "Blue",
		"Horses Neck" => "Yellow",
		"Hot Curry" => "Yellow",
		"Hot Magenta" => "Red",
		"Hot Pink" => "Pink",
		"Hot Purple" => "Violet",
		"Hot Toddy" => "Yellow",
		"Humming Bird" => "Green",
		"Hunter Green" => "Green",
		"Hurricane" => "Brown",
		"Husk" => "Yellow",
		"Ice Cold" => "Green",
		"Iceberg" => "Green",
		"Illusion" => "Red",
		"Inch Worm" => "Green",
		"Indian Red" => "Red",
		"Indian Tan" => "Brown",
		"Indigo" => "Violet",
		"Indochine" => "Orange",
		"International Klein Blue" => "Blue",
		"International Orange" => "Orange",
		"Iris Blue" => "Blue",
		"Irish Coffee" => "Brown",
		"Iron" => "Grey",
		"Ironside Grey" => "Grey",
		"Ironstone" => "Brown",
		"Islamic Green" => "Green",
		"Island Spice" => "Yellow",
		"Ivory" => "White",
		"Jacarta" => "Violet",
		"Jacko Bean" => "Brown",
		"Jacksons Purple" => "Violet",
		"Jade" => "Green",
		"Jaffa" => "Orange",
		"Jagged Ice" => "Green",
		"Jagger" => "Violet",
		"Jaguar" => "Blue",
		"Jambalaya" => "Brown",
		"Japanese Laurel" => "Green",
		"Japonica" => "Orange",
		"Java" => "Green",
		"Jazz" => "Red",
		"Jazzberry Jam" => "Red",
		"Jelly Bean" => "Blue",
		"Jet Stream" => "Green",
		"Jewel" => "Green",
		"Jon" => "Grey",
		"Jonquil" => "Green",
		"Jordy Blue" => "Blue",
		"Judge Grey" => "Brown",
		"Jumbo" => "Grey",
		"Jungle Green" => "Green",
		"Jungle Mist" => "Green",
		"Juniper" => "Green",
		"Just Right" => "Orange",
		"Kabul" => "Brown",
		"Kaitoke Green" => "Green",
		"Kangaroo" => "Green",
		"Karaka" => "Green",
		"Karry" => "Orange",
		"Kashmir Blue" => "Blue",
		"Kelly Green" => "Green",
		"Kelp" => "Green",
		"Kenyan Copper" => "Red",
		"Keppel" => "Green",
		"Khaki" => "Yellow",
		"Kidnapper" => "Green",
		"Kilamanjaro" => "Grey",
		"Killarney" => "Green",
		"Kimberly" => "Violet",
		"Kingfisher Daisy" => "Violet",
		"Kobi" => "Red",
		"Kokoda" => "Green",
		"Korma" => "Orange",
		"Koromiko" => "Yellow",
		"Kournikova" => "Yellow",
		"La Palma" => "Green",
		"La Rioja" => "Green",
		"Las Palmas" => "Green",
		"Laser" => "Yellow",
		"Laser Lemon" => "Yellow",
		"Laurel" => "Green",
		"Lavender" => "Violet",
		"Lavender Blue" => "Blue",
		"Lavender Blush" => "Violet",
		"Lavender Grey" => "Grey",
		"Lavender Pink" => "Pink",
		"Lavender Rose" => "Red",
		"Lawn Green" => "Green",
		"Leather" => "Brown",
		"Lemon" => "Yellow",
		"Lemon Chiffon" => "Yellow",
		"Lemon Ginger" => "Yellow",
		"Lemon Grass" => "Green",
		"Licorice" => "Blue",
		"Light Blue" => "Blue",
		"Light Coral" => "Orange",
		"Light Cyan" => "Blue",
		"Light Goldenrod" => "Yellow",
		"Light Goldenrod Yellow" => "Yellow",
		"Light Green" => "Green",
		"Light Grey" => "Grey",
		"Light Pink" => "Pink",
		"Light Salmon" => "Orange",
		"Light Sea Green" => "Green",
		"Light Sky Blue" => "Blue",
		"Light Slate Blue" => "Blue",
		"Light Slate Grey" => "Grey",
		"Light Steel Blue" => "Blue",
		"Light Wood" => "Brown",
		"Light Yellow" => "Yellow",
		"Lightning Yellow" => "Yellow",
		"Lilac" => "Violet",
		"Lilac Bush" => "Violet",
		"Lily" => "Violet",
		"Lily White" => "Grey",
		"Lima" => "Green",
		"Lime" => "Green",
		"Lime Green" => "Green",
		"Limeade" => "Green",
		"Limerick" => "Green",
		"Linen" => "White",
		"Link Water" => "Blue",
		"Lipstick" => "Red",
		"Liver" => "Brown",
		"Livid Brown" => "Brown",
		"Loafer" => "Green",
		"Loblolly" => "Green",
		"Lochinvar" => "Green",
		"Lochmara" => "Blue",
		"Locust" => "Green",
		"Log Cabin" => "Green",
		"Logan" => "Blue",
		"Lola" => "Violet",
		"London Hue" => "Violet",
		"Lonestar" => "Red",
		"Lotus" => "Brown",
		"Loulou" => "Violet",
		"Lucky" => "Green",
		"Lucky Point" => "Blue",
		"Lunar Green" => "Green",
		"Lusty" => "Red",
		"Luxor Gold" => "Yellow",
		"Lynch" => "Blue",
		"Mabel" => "Blue",
		"Macaroni And Cheese" => "Orange",
		"Madang" => "Green",
		"Madison" => "Blue",
		"Madras" => "Brown",
		"Magenta" => "Violet",
		"Magic Mint" => "Green",
		"Magnolia" => "White",
		"Mahogany" => "Brown",
		"Mai Tai" => "Orange",
		"Maire" => "Yellow",
		"Maize" => "Yellow",
		"Makara" => "Brown",
		"Mako" => "Grey",
		"Malachite" => "Green",
		"Malachite Green" => "Green",
		"Malibu" => "Blue",
		"Mallard" => "Green",
		"Malta" => "Brown",
		"Mamba" => "Violet",
		"Manatee" => "Blue",
		"Mandalay" => "Yellow",
		"Mandarian Orange" => "Orange",
		"Mandy" => "Red",
		"Mandys Pink" => "Pink",
		"Mango Tango" => "Orange",
		"Manhattan" => "Orange",
		"Mantis" => "Green",
		"Mantle" => "Green",
		"Manz" => "Green",
		"Mardi Gras" => "Violet",
		"Marigold" => "Yellow",
		"Mariner" => "Blue",
		"Maroon" => "Brown",
		"Marshland" => "Green",
		"Martini" => "Brown",
		"Martinique" => "Violet",
		"Marzipan" => "Yellow",
		"Masala" => "Brown",
		"Matisse" => "Blue",
		"Matrix" => "Red",
		"Matterhorn" => "Grey",
		"Mauve" => "Violet",
		"Mauve Taupe" => "Red",
		"Mauvelous" => "Red",
		"Maverick" => "Violet",
		"Maya Blue" => "Blue",
		"McKenzie" => "Orange",
		"Medium Aquamarine" => "Blue",
		"Medium Blue" => "Blue",
		"Medium Carmine" => "Red",
		"Medium Goldenrod" => "Yellow",
		"Medium Orchid" => "Violet",
		"Medium Purple" => "Violet",
		"Medium Sea Green" => "Green",
		"Medium Slate Blue" => "Blue",
		"Medium Spring Green" => "Green",
		"Medium Turquoise" => "Blue",
		"Medium Violet Red" => "Red",
		"Medium Wood" => "Brown",
		"Melanie" => "Red",
		"Melanzane" => "Violet",
		"Melon" => "Red",
		"Melrose" => "Violet",
		"Mercury" => "Grey",
		"Merino" => "Yellow",
		"Merlin" => "Grey",
		"Merlot" => "Red",
		"Metallic Bronze" => "Red",
		"Metallic Copper" => "Red",
		"Metallic Gold" => "Yellow",
		"Meteor" => "Orange",
		"Meteorite" => "Violet",
		"Mexican Red" => "Red",
		"Mid Grey" => "Grey",
		"Midnight" => "Blue",
		"Midnight Blue" => "Blue",
		"Midnight Express" => "Blue",
		"Midnight Moss" => "Green",
		"Mikado" => "Brown",
		"Milan" => "Green",
		"Milano Red" => "Red",
		"Milk Punch" => "Yellow",
		"Milk White" => "Grey",
		"Millbrook" => "Brown",
		"Mimosa" => "Green",
		"Mindaro" => "Green",
		"Mine Shaft" => "Blue",
		"Mineral Green" => "Green",
		"Ming" => "Green",
		"Minsk" => "Violet",
		"Mint Cream" => "White",
		"Mint Green" => "Green",
		"Mint Julep" => "Green",
		"Mint Tulip" => "Green",
		"Mirage" => "Blue",
		"Mischka" => "Blue",
		"Mist Grey" => "Grey",
		"Misty Rose" => "Violet",
		"Mobster" => "Violet",
		"Moccaccino" => "Red",
		"Moccasin" => "Yellow",
		"Mocha" => "Red",
		"Mojo" => "Red",
		"Mona Lisa" => "Red",
		"Monarch" => "Red",
		"Mondo" => "Brown",
		"Mongoose" => "Brown",
		"Monsoon" => "Grey",
		"Montana" => "Grey",
		"Monte Carlo" => "Green",
		"Moody Blue" => "Violet",
		"Moon Glow" => "Green",
		"Moon Mist" => "Green",
		"Moon Raker" => "Violet",
		"Moon Yellow" => "Yellow",
		"Morning Glory" => "Blue",
		"Morocco Brown" => "Brown",
		"Mortar" => "Grey",
		"Mosque" => "Green",
		"Moss Green" => "Green",
		"Mountain Meadow" => "Green",
		"Mountain Mist" => "Grey",
		"Mountbatten Pink" => "Pink",
		"Muddy Waters" => "Yellow",
		"Muesli" => "Brown",
		"Mulberry" => "Violet",
		"Mule Fawn" => "Brown",
		"Mulled Wine" => "Violet",
		"Mustard" => "Yellow",
		"My Pink" => "Pink",
		"My Sin" => "Yellow",
		"Myrtle" => "Green",
		"Mystic" => "Grey",
		"Nandor" => "Green",
		"Napa" => "Yellow",
		"Narvik" => "Green",
		"Navajo White" => "Brown",
		"Navy" => "Blue",
		"Navy Blue" => "Blue",
		"Nebula" => "Green",
		"Negroni" => "Orange",
		"Neon Blue" => "Blue",
		"Neon Carrot" => "Orange",
		"Neon Pink" => "Pink",
		"Nepal" => "Blue",
		"Neptune" => "Green",
		"Nero" => "Grey",
		"Neutral Green" => "Green",
		"Nevada" => "Grey",
		"New Amber" => "Orange",
		"New Midnight Blue" => "Blue",
		"New Orleans" => "Yellow",
		"New Tan" => "Brown",
		"New York Pink" => "Pink",
		"Niagara" => "Green",
		"Night Rider" => "Grey",
		"Night Shadz" => "Red",
		"Nile Blue" => "Blue",
		"Nobel" => "Grey",
		"Nomad" => "Yellow",
		"Nordic" => "Blue",
		"Norway" => "Green",
		"Nugget" => "Yellow",
		"Nutmeg" => "Brown",
		"Oasis" => "Yellow",
		"Observatory" => "Green",
		"Ocean Green" => "Green",
		"Ochre" => "Brown",
		"Off Green" => "Green",
		"Off Yellow" => "Yellow",
		"Oil" => "Grey",
		"Old Brick" => "Red",
		"Old Copper" => "Red",
		"Old Gold" => "Yellow",
		"Old Lace" => "White",
		"Old Lavender" => "Violet",
		"Old Rose" => "Red",
		"Olive" => "Green",
		"Olive Drab" => "Green",
		"Olive Green" => "Green",
		"Olive Haze" => "Yellow",
		"Olivetone" => "Green",
		"Olivine" => "Orange",
		"Onahau" => "Blue",
		"Onion" => "Yellow",
		"Opal" => "Green",
		"Opium" => "Brown",
		"Oracle" => "Green",
		"Orange" => "Orange",
		"Orange Peel" => "Orange",
		"Orange Red" => "Orange",
		"Orange Roughy" => "Orange",
		"Orange White" => "Yellow",
		"Orchid" => "Violet",
		"Orchid White" => "Yellow",
		"Orient" => "Blue",
		"Oriental Pink" => "Pink",
		"Orinoco" => "Green",
		"Oslo Grey" => "Grey",
		"Ottoman" => "Green",
		"Outer Space" => "Grey",
		"Outrageous Orange" => "Orange",
		"Oxford Blue" => "Blue",
		"Oxley" => "Green",
		"Oyster Bay" => "Blue",
		"Oyster Pink" => "Pink",
		"Paarl" => "Orange",
		"Pablo" => "Yellow",
		"Pacific Blue" => "Blue",
		"Paco" => "Brown",
		"Padua" => "Green",
		"Palatinate Purple" => "Violet",
		"Pale Brown" => "Brown",
		"Pale Chestnut" => "Red",
		"Pale Cornflower Blue" => "Blue",
		"Pale Goldenrod" => "Yellow",
		"Pale Green" => "Green",
		"Pale Leaf" => "Green",
		"Pale Magenta" => "Violet",
		"Pale Oyster" => "Brown",
		"Pale Pink" => "Pink",
		"Pale Prim" => "Green",
		"Pale Rose" => "Red",
		"Pale Sky" => "Blue",
		"Pale Slate" => "Grey",
		"Pale Taupe" => "Grey",
		"Pale Turquoise" => "Blue",
		"Pale Violet Red" => "Red",
		"Palm Green" => "Green",
		"Palm Leaf" => "Green",
		"Pampas" => "Grey",
		"Panache" => "Green",
		"Pancho" => "Orange",
		"Panda" => "Yellow",
		"Papaya Whip" => "Yellow",
		"Paprika" => "Red",
		"Paradiso" => "Green",
		"Parchment" => "Yellow",
		"Paris Daisy" => "Green",
		"Paris M" => "Violet",
		"Paris White" => "Green",
		"Parsley" => "Green",
		"Pastel Green" => "Green",
		"Patina" => "Green",
		"Pattens Blue" => "Blue",
		"Paua" => "Violet",
		"Pavlova" => "Yellow",
		"Payne's Grey" => "Grey",
		"Peach" => "Orange",
		"Peach Puff" => "Yellow",
		"Peach-Orange" => "Orange",
		"Peach-Yellow" => "Yellow",
		"Peanut" => "Brown",
		"Pear" => "Yellow",
		"Pearl Bush" => "Orange",
		"Pearl Lusta" => "Yellow",
		"Peat" => "Yellow",
		"Pelorous" => "Blue",
		"Peppermint" => "Green",
		"Perano" => "Blue",
		"Perfume" => "Violet",
		"Periglacial Blue" => "Green",
		"Periwinkle" => "Blue",
		"Persian Blue" => "Blue",
		"Persian Green" => "Green",
		"Persian Indigo" => "Violet",
		"Persian Pink" => "Pink",
		"Persian Plum" => "Red",
		"Persian Red" => "Red",
		"Persian Rose" => "Red",
		"Persimmon" => "Red",
		"Peru" => "Brown",
		"Peru Tan" => "Orange",
		"Pesto" => "Yellow",
		"Petite Orchid" => "Red",
		"Pewter" => "Green",
		"Pharlap" => "Brown",
		"Picasso" => "Green",
		"Picton Blue" => "Blue",
		"Pig Pink" => "Pink",
		"Pigment Green" => "Green",
		"Pine Cone" => "Brown",
		"Pine Glade" => "Green",
		"Pine Green" => "Green",
		"Pine Tree" => "Green",
		"Pink" => "Pink",
		"Pink Flamingo" => "Pink",
		"Pink Flare" => "Pink",
		"Pink Lace" => "Pink",
		"Pink Lady" => "Pink",
		"Pink Swan" => "Pink",
		"Piper" => "Orange",
		"Pipi" => "Yellow",
		"Pippin" => "Red",
		"Pirate Gold" => "Yellow",
		"Pixie Green" => "Green",
		"Pizazz" => "Orange",
		"Pizza" => "Yellow",
		"Plantation" => "Green",
		"Plum" => "Violet",
		"Pohutukawa" => "Red",
		"Polar" => "Green",
		"Polo Blue" => "Blue",
		"Pompadour" => "Violet",
		"Porcelain" => "Grey",
		"Porsche" => "Orange",
		"Port Gore" => "Blue",
		"Portafino" => "Green",
		"Portage" => "Blue",
		"Portica" => "Yellow",
		"Pot Pourri" => "Orange",
		"Potters Clay" => "Brown",
		"Powder Blue" => "Blue",
		"Prairie Sand" => "Red",
		"Prelude" => "Violet",
		"Prim" => "Violet",
		"Primrose" => "Green",
		"Promenade" => "Green",
		"Provincial Pink" => "Pink",
		"Prussian Blue" => "Blue",
		"Psychedelic Purple" => "Violet",
		"Puce" => "Red",
		"Pueblo" => "Orange",
		"Puerto Rico" => "Green",
		"Pumice" => "Green",
		"Pumpkin" => "Orange",
		"Punga" => "Yellow",
		"Purple" => "Violet",
		"Purple Heart" => "Violet",
		"Purple Mountain's Majesty" => "Violet",
		"Purple Taupe" => "Grey",
		"Putty" => "Yellow",
		"Quarter Pearl Lusta" => "Green",
		"Quarter Spanish White" => "Yellow",
		"Quartz" => "White",
		"Quicksand" => "Brown",
		"Quill Grey" => "Grey",
		"Quincy" => "Brown",
		"Racing Green" => "Green",
		"Radical Red" => "Red",
		"Raffia" => "Yellow",
		"Rain Forest" => "Green",
		"Rainee" => "Green",
		"Rajah" => "Orange",
		"Rangoon Green" => "Green",
		"Raven" => "Blue",
		"Raw Sienna" => "Brown",
		"Raw Umber" => "Brown",
		"Razzle Dazzle Rose" => "Red",
		"Razzmatazz" => "Red",
		"Rebel" => "Brown",
		"Red" => "Red",
		"Red Berry" => "Red",
		"Red Damask" => "Orange",
		"Red Devil" => "Red",
		"Red Orange" => "Orange",
		"Red Oxide" => "Red",
		"Red Robin" => "Red",
		"Red Stage" => "Orange",
		"Medium Red Violet" => "Violet",
		"Redwood" => "Red",
		"Reef" => "Green",
		"Reef Gold" => "Yellow",
		"Regal Blue" => "Blue",
		"Regent Grey" => "Blue",
		"Regent St Blue" => "Blue",
		"Remy" => "Red",
		"Reno Sand" => "Orange",
		"Resolution Blue" => "Blue",
		"Revolver" => "Violet",
		"Rhino" => "Blue",
		"Rice Cake" => "Green",
		"Rice Flower" => "Green",
		"Rich Blue" => "Blue",
		"Rich Gold" => "Orange",
		"Rio Grande" => "Green",
		"Riptide" => "Green",
		"River Bed" => "Blue",
		"Rob Roy" => "Yellow",
		"Robin's Egg Blue" => "Blue",
		"Rock" => "Brown",
		"Rock Blue" => "Blue",
		"Rock Spray" => "Orange",
		"Rodeo Dust" => "Brown",
		"Rolling Stone" => "Green",
		"Roman" => "Red",
		"Roman Coffee" => "Brown",
		"Romance" => "Grey",
		"Romantic" => "Orange",
		"Ronchi" => "Yellow",
		"Roof Terracotta" => "Red",
		"Rope" => "Orange",
		"Rose" => "Red",
		"Rose Bud" => "Red",
		"Rose Bud Cherry" => "Red",
		"Rose Of Sharon" => "Orange",
		"Rose Taupe" => "Violet",
		"Rose White" => "Red",
		"Rosy Brown" => "Brown",
		"Roti" => "Yellow",
		"Rouge" => "Red",
		"Royal Blue" => "Blue",
		"Royal Heath" => "Red",
		"Royal Purple" => "Violet",
		"Ruby" => "Red",
		"Rum" => "Violet",
		"Rum Swizzle" => "Green",
		"Russet" => "Brown",
		"Russett" => "Brown",
		"Rust" => "Red",
		"Rustic Red" => "Red",
		"Rusty Nail" => "Orange",
		"Saddle" => "Brown",
		"Saddle Brown" => "Brown",
		"Safety Orange" => "Orange",
		"Saffron" => "Yellow",
		"Sage" => "Green",
		"Sahara" => "Yellow",
		"Sail" => "Blue",
		"Salem" => "Green",
		"Salmon" => "Red",
		"Salomie" => "Yellow",
		"Salt Box" => "Violet",
		"Saltpan" => "Grey",
		"Sambuca" => "Brown",
		"San Felix" => "Green",
		"San Juan" => "Blue",
		"San Marino" => "Blue",
		"Sand Dune" => "Brown",
		"Sandal" => "Brown",
		"Sandrift" => "Brown",
		"Sandstone" => "Brown",
		"Sandwisp" => "Yellow",
		"Sandy Beach" => "Orange",
		"Sandy Brown" => "Brown",
		"Sangria" => "Red",
		"Sanguine Brown" => "Red",
		"Santas Grey" => "Blue",
		"Sante Fe" => "Orange",
		"Sapling" => "Yellow",
		"Sapphire" => "Blue",
		"Saratoga" => "Green",
		"Sauvignon" => "Red",
		"Sazerac" => "Orange",
		"Scampi" => "Violet",
		"Scandal" => "Green",
		"Scarlet" => "Red",
		"Scarlet Gum" => "Violet",
		"Scarlett" => "Red",
		"Scarpa Flow" => "Grey",
		"Schist" => "Green",
		"School Bus Yellow" => "Yellow",
		"Schooner" => "Brown",
		"Scooter" => "Blue",
		"Scorpion" => "Grey",
		"Scotch Mist" => "Yellow",
		"Screamin' Green" => "Green",
		"Scrub" => "Green",
		"Sea Buckthorn" => "Orange",
		"Sea Fog" => "Grey",
		"Sea Green" => "Green",
		"Sea Mist" => "Green",
		"Sea Nymph" => "Green",
		"Sea Pink" => "Pink",
		"Seagull" => "Blue",
		"Seal Brown" => "Brown",
		"Seance" => "Violet",
		"Seashell" => "White",
		"Seaweed" => "Green",
		"Selago" => "Violet",
		"Selective Yellow" => "Yellow",
		"Semi-Sweet Chocolate" => "Brown",
		"Sepia" => "Brown",
		"Serenade" => "Orange",
		"Shadow" => "Green",
		"Shadow Green" => "Green",
		"Shady Lady" => "Grey",
		"Shakespeare" => "Blue",
		"Shalimar" => "Green",
		"Shamrock" => "Green",
		"Shamrock Green" => "Green",
		"Shark" => "Grey",
		"Sherpa Blue" => "Green",
		"Sherwood Green" => "Green",
		"Shilo" => "Red",
		"Shingle Fawn" => "Brown",
		"Ship Cove" => "Blue",
		"Ship Grey" => "Grey",
		"Shiraz" => "Red",
		"Shocking" => "Violet",
		"Shocking Pink" => "Pink",
		"Shuttle Grey" => "Grey",
		"Siam" => "Green",
		"Sidecar" => "Yellow",
		"Sienna" => "Brown",
		"Silk" => "Brown",
		"Silver" => "Grey",
		"Silver Chalice" => "Grey",
		"Silver Sand" => "Grey",
		"Silver Tree" => "Green",
		"Sinbad" => "Green",
		"Siren" => "Red",
		"Sirocco" => "Green",
		"Sisal" => "Yellow",
		"Skeptic" => "Green",
		"Sky Blue" => "Blue",
		"Slate Blue" => "Blue",
		"Slate Grey" => "Grey",
		"Slugger" => "Brown",
		"Smalt" => "Blue",
		"Smalt Blue" => "Blue",
		"Smoke Tree" => "Orange",
		"Smoky" => "Violet",
		"Snow" => "White",
		"Snow Drift" => "Grey",
		"Snow Flurry" => "Green",
		"Snowy Mint" => "Green",
		"Snuff" => "Violet",
		"Soapstone" => "Grey",
		"Soft Amber" => "Yellow",
		"Soft Peach" => "Red",
		"Solid Pink" => "Pink",
		"Solitaire" => "Yellow",
		"Solitude" => "Blue",
		"Sorbus" => "Orange",
		"Sorrell Brown" => "Brown",
		"Sour Dough" => "Brown",
		"Soya Bean" => "Brown",
		"Space Shuttle" => "Brown",
		"Spanish Green" => "Green",
		"Spanish White" => "Yellow",
		"Spectra" => "Green",
		"Spice" => "Brown",
		"Spicy Mix" => "Brown",
		"Spicy Pink" => "Pink",
		"Spindle" => "Blue",
		"Splash" => "Yellow",
		"Spray" => "Blue",
		"Spring Bud" => "Green",
		"Spring Green" => "Green",
		"Spring Rain" => "Green",
		"Spring Sun" => "Green",
		"Spring Wood" => "Grey",
		"Sprout" => "Green",
		"Spun Pearl" => "Blue",
		"Squirrel" => "Brown",
		"St Tropaz" => "Blue",
		"Stack" => "Grey",
		"Star Dust" => "Grey",
		"Stark White" => "Yellow",
		"Starship" => "Green",
		"Steel Blue" => "Blue",
		"Steel Grey" => "Grey",
		"Stiletto" => "Red",
		"Stonewall" => "Yellow",
		"Storm Dust" => "Grey",
		"Storm Grey" => "Blue",
		"Straw" => "Yellow",
		"Strikemaster" => "Violet",
		"Stromboli" => "Green",
		"Studio" => "Violet",
		"Submarine" => "Blue",
		"Sugar Cane" => "Green",
		"Sulu" => "Green",
		"Summer Green" => "Green",
		"Summer Sky" => "Blue",
		"Sun" => "Orange",
		"Sundance" => "Yellow",
		"Sundown" => "Red",
		"Sunflower" => "Yellow",
		"Sunglo" => "Red",
		"Sunglow" => "Orange",
		"Sunset" => "Red",
		"Sunset Orange" => "Orange",
		"Sunshade" => "Orange",
		"Supernova" => "Yellow",
		"Surf" => "Green",
		"Surf Crest" => "Green",
		"Surfie Green" => "Green",
		"Sushi" => "Green",
		"Suva Grey" => "Grey",
		"Swamp" => "Green",
		"Swans Down" => "Grey",
		"Sweet Corn" => "Yellow",
		"Sweet Pink" => "Pink",
		"Swirl" => "Grey",
		"Swiss Coffee" => "Grey",
		"Tacao" => "Orange",
		"Tacha" => "Yellow",
		"Tahiti Gold" => "Orange",
		"Tahuna Sands" => "Yellow",
		"Tall Poppy" => "Red",
		"Tallow" => "Yellow",
		"Tamarillo" => "Red",
		"Tan" => "Brown",
		"Tana" => "Green",
		"Tangaroa" => "Blue",
		"Tangerine" => "Orange",
		"Tangerine Yellow" => "Yellow",
		"Tango" => "Orange",
		"Tapa" => "Green",
		"Tapestry" => "Red",
		"Tara" => "Green",
		"Tarawera" => "Blue",
		"Tasman" => "Grey",
		"Taupe" => "Grey",
		"Taupe Grey" => "Grey",
		"Tawny Port" => "Red",
		"Tax Break" => "Blue",
		"Te Papa Green" => "Green",
		"Tea" => "Yellow",
		"Tea Green" => "Green",
		"Tea Rose" => "Orange",
		"Teak" => "Yellow",
		"Teal" => "Blue",
		"Teal Blue" => "Blue",
		"Temptress" => "Brown",
		"Tenne (Tawny)" => "Orange",
		"Tequila" => "Yellow",
		"Terra Cotta" => "Red",
		"Texas" => "Green",
		"Texas Rose" => "Orange",
		"Thatch" => "Brown",
		"Thatch Green" => "Yellow",
		"Thistle" => "Violet",
		"Thunder" => "Grey",
		"Thunderbird" => "Red",
		"Tia Maria" => "Orange",
		"Tiara" => "Grey",
		"Tiber" => "Green",
		"Tickle Me Pink" => "Pink",
		"Tidal" => "Green",
		"Tide" => "Brown",
		"Timber Green" => "Green",
		"Timberwolf" => "Grey",
		"Titan White" => "Violet",
		"Toast" => "Brown",
		"Tobacco Brown" => "Brown",
		"Tobago" => "Brown",
		"Toledo" => "Violet",
		"Tolopea" => "Violet",
		"Tom Thumb" => "Green",
		"Tomato" => "Red",
		"Tonys Pink" => "Pink",
		"Topaz" => "Violet",
		"Torch Red" => "Red",
		"Torea Bay" => "Blue",
		"Tory Blue" => "Blue",
		"Tosca" => "Red",
		"Tower Grey" => "Green",
		"Tradewind" => "Green",
		"Tranquil" => "Blue",
		"Travertine" => "Green",
		"Tree Poppy" => "Orange",
		"Trendy Green" => "Green",
		"Trendy Pink" => "Pink",
		"Trinidad" => "Orange",
		"Tropical Blue" => "Blue",
		"Tropical Rain Forest" => "Green",
		"Trout" => "Grey",
		"True V" => "Violet",
		"Tuatara" => "Grey",
		"Tuft Bush" => "Orange",
		"Tulip Tree" => "Yellow",
		"Tumbleweed" => "Brown",
		"Tuna" => "Grey",
		"Tundora" => "Grey",
		"Turbo" => "Yellow",
		"Turkish Rose" => "Red",
		"Turmeric" => "Yellow",
		"Turquoise" => "Blue",
		"Turquoise Blue" => "Blue",
		"Turtle Green" => "Green",
		"Tuscany" => "Orange",
		"Tusk" => "Green",
		"Tussock" => "Yellow",
		"Tutu" => "Red",
		"Twilight" => "Violet",
		"Twilight Blue" => "Grey",
		"Twine" => "Yellow",
		"Tyrian Purple" => "Violet",
		"Ultra Pink" => "Pink",
		"Ultramarine" => "Blue",
		"Valencia" => "Red",
		"Valentino" => "Violet",
		"Valhalla" => "Violet",
		"Van Cleef" => "Brown",
		"Vanilla" => "Brown",
		"Vanilla Ice" => "Red",
		"Varden" => "Yellow",
		"Venetian Red" => "Red",
		"Venice Blue" => "Blue",
		"Venus" => "Violet",
		"Verdigris" => "Grey",
		"Verdun Green" => "Green",
		"Vermilion" => "Red",
		"Very Dark Brown" => "Brown",
		"Very Light Grey" => "Grey",
		"Vesuvius" => "Orange",
		"Victoria" => "Violet",
		"Vida Loca" => "Green",
		"Viking" => "Blue",
		"Vin Rouge" => "Red",
		"Viola" => "Red",
		"Violent Violet" => "Violet",
		"Violet" => "Violet",
		"Violet Blue" => "Violet",
		"Violet Red" => "Red",
		"Viridian" => "Blue",
		"Viridian Green" => "Green",
		"Vis Vis" => "Yellow",
		"Vista Blue" => "Green",
		"Vista White" => "Grey",
		"Vivid Tangerine" => "Orange",
		"Vivid Violet" => "Violet",
		"Volcano" => "Red",
		"Voodoo" => "Violet",
		"Vulcan" => "Grey",
		"Wafer" => "Orange",
		"Waikawa Grey" => "Blue",
		"Waiouru" => "Green",
		"Wan White" => "Grey",
		"Wasabi" => "Green",
		"Water Leaf" => "Green",
		"Watercourse" => "Green",
		"Wattle" => "Green",
		"Watusi" => "Orange",
		"Wax Flower" => "Orange",
		"We Peep" => "Red",
		"Wedgewood" => "Blue",
		"Well Read" => "Red",
		"West Coast" => "Yellow",
		"West Side" => "Orange",
		"Westar" => "Grey",
		"Wewak" => "Red",
		"Wheat" => "Brown",
		"Wheatfield" => "Yellow",
		"Whiskey" => "Orange",
		"Whiskey Sour" => "Orange",
		"Whisper" => "Grey",
		"White" => "White",
		"White Ice" => "Green",
		"White Lilac" => "Blue",
		"White Linen" => "Grey",
		"White Nectar" => "Green",
		"White Pointer" => "Grey",
		"White Rock" => "Green",
		"White Smoke" => "White",
		"Wild Blue Yonder" => "Blue",
		"Wild Rice" => "Green",
		"Wild Sand" => "Grey",
		"Wild Strawberry" => "Red",
		"Wild Watermelon" => "Red",
		"Wild Willow" => "Green",
		"William" => "Green",
		"Willow Brook" => "Green",
		"Willow Grove" => "Green",
		"Windsor" => "Violet",
		"Wine Berry" => "Red",
		"Winter Hazel" => "Yellow",
		"Wisp Pink" => "Pink",
		"Wisteria" => "Violet",
		"Wistful" => "Blue",
		"Witch Haze" => "Green",
		"Wood Bark" => "Brown",
		"Woodburn" => "Brown",
		"Woodland" => "Green",
		"Woodrush" => "Yellow",
		"Woodsmoke" => "Grey",
		"Woody Brown" => "Brown",
		"Xanadu" => "Green",
		"Yellow" => "Yellow",
		"Yellow Green" => "Green",
		"Yellow Metal" => "Yellow",
		"Yellow Orange" => "Orange",
		"Yellow Sea" => "Yellow",
		"Your Pink" => "Pink",
		"Yukon Gold" => "Yellow",
		"Yuma" => "Yellow",
		"Zambezi" => "Brown",
		"Zanah" => "Green",
		"Zest" => "Orange",
		"Zeus" => "Grey",
		"Ziggurat" => "Blue",
		"Zinnwaldite" => "Brown",
		"Zircon" => "Grey",
		"Zombie" => "Yellow",
		"Zorba" => "Brown",
		"Zuccini" => "Green",);
		
		$GetMostCommonColors = new GetMostCommonColors();
        
        echo "DEBUG! get colors for ${path}\n";
        
		$colors_array = $GetMostCommonColors->Get_Color($path, 20); 

        if ($this->extended_log) {
            print_r($colors_array);
        }
        
		$color_summary = array();

		foreach ($colors_array as $color_code => $color_percentage) {
			$nearest_color = getNearestColor($color_code, $palette);
			$main_color = $main_colors_key[$nearest_color];
			echo "${color_code} ${nearest_color} (${main_color})\n";
			
			$color_summary[$main_color] += $color_percentage;
		}

		$wanted_colors = array();

		foreach ($color_summary as $color => $percentage) {
			if ($percentage > 0.1) {
				$wanted_colors[] = $color;
			}	
		}
        
        if ($this->extended_log) {
            echo "DEBUG: Wanted Colors\n";
            print_r($wanted_colors);
        }
        
		return $wanted_colors;
	}
}

/**
 * This class can be used to get the most common colors in an image.
 * It needs one parameter:
 * 	$image - the filename of the image you want to process.
 * Optional parameters:
 *
 *	$count - how many colors should be returned. 0 mmeans all. default=20
 *	$reduce_brightness - reduce (not eliminate) brightness variants? default=true
 *	$reduce_gradients - reduce (not eliminate) gradient variants? default=true
 *	$delta - the amount of gap when quantizing color values.
 *		Lower values mean more accurate colors. default=16
 *
 * Author: 	Csongor Zalatnai
 *
 * Modified By: Kepler Gelotte - Added the gradient and brightness variation
 * 	reduction routines. Kudos to Csongor for an excellent class. The original
 * 	version can be found at:
 *
 *	http://www.phpclasses.org/browse/package/3370.html
 *
 */
class GetMostCommonColors
{
	var $PREVIEW_WIDTH    = 150;
	var $PREVIEW_HEIGHT   = 150;

	var $error;

	/**
	 * Returns the colors of the image in an array, ordered in descending order, where the keys are the colors, and the values are the count of the color.
	 *
	 * @return array
	 */
	function Get_Color( $img, $count=20, $reduce_brightness=true, $reduce_gradients=true, $delta=16 )
	{
		if (is_readable( $img ))
		{
			if ( $delta > 2 )
			{
				$half_delta = $delta / 2 - 1;
			}
			else
			{
				$half_delta = 0;
			}
			// WE HAVE TO RESIZE THE IMAGE, BECAUSE WE ONLY NEED THE MOST SIGNIFICANT COLORS.
			$size = GetImageSize($img);
			$scale = 1;
			if ($size[0]>0)
			$scale = min($this->PREVIEW_WIDTH/$size[0], $this->PREVIEW_HEIGHT/$size[1]);
			if ($scale < 1)
			{
				$width = floor($scale*$size[0]);
				$height = floor($scale*$size[1]);
			}
			else
			{
				$width = $size[0];
				$height = $size[1];
			}
			$image_resized = imagecreatetruecolor($width, $height);
			if ($size[2] == 1)
			$image_orig = imagecreatefromgif($img);
			if ($size[2] == 2)
			$image_orig = imagecreatefromjpeg($img);
			if ($size[2] == 3)
			$image_orig = imagecreatefrompng($img);
			// WE NEED NEAREST NEIGHBOR RESIZING, BECAUSE IT DOESN'T ALTER THE COLORS
			imagecopyresampled($image_resized, $image_orig, 0, 0, 0, 0, $width, $height, $size[0], $size[1]);
			$im = $image_resized;
			$imgWidth = imagesx($im);
			$imgHeight = imagesy($im);
			$total_pixel_count = 0;
			for ($y=0; $y < $imgHeight; $y++)
			{
				for ($x=0; $x < $imgWidth; $x++)
				{
					$total_pixel_count++;
					$index = imagecolorat($im,$x,$y);
					$colors = imagecolorsforindex($im,$index);
					// ROUND THE COLORS, TO REDUCE THE NUMBER OF DUPLICATE COLORS
					if ( $delta > 1 )
					{
						$colors['red'] = intval((($colors['red'])+$half_delta)/$delta)*$delta;
						$colors['green'] = intval((($colors['green'])+$half_delta)/$delta)*$delta;
						$colors['blue'] = intval((($colors['blue'])+$half_delta)/$delta)*$delta;
						if ($colors['red'] >= 256)
						{
							$colors['red'] = 255;
						}
						if ($colors['green'] >= 256)
						{
							$colors['green'] = 255;
						}
						if ($colors['blue'] >= 256)
						{
							$colors['blue'] = 255;
						}

					}

					$hex = substr("0".dechex($colors['red']),-2).substr("0".dechex($colors['green']),-2).substr("0".dechex($colors['blue']),-2);

					if ( ! isset( $hexarray[$hex] ) )
					{
						$hexarray[$hex] = 1;
					}
					else
					{
						$hexarray[$hex]++;
					}
				}
			}

			// Reduce gradient colors
			if ( $reduce_gradients )
			{
				// if you want to *eliminate* gradient variations use:
				// ksort( $hexarray );
				arsort( $hexarray, SORT_NUMERIC );

				$gradients = array();
				foreach ($hexarray as $hex => $num)
				{
					if ( ! isset($gradients[$hex]) )
					{
						$new_hex = $this->_find_adjacent( $hex, $gradients, $delta );
						$gradients[$hex] = $new_hex;
					}
					else
					{
						$new_hex = $gradients[$hex];
					}

					if ($hex != $new_hex)
					{
						$hexarray[$hex] = 0;
						$hexarray[$new_hex] += $num;
					}
				}
			}

			// Reduce brightness variations
			if ( $reduce_brightness )
			{
				// if you want to *eliminate* brightness variations use:
				// ksort( $hexarray );
				arsort( $hexarray, SORT_NUMERIC );

				$brightness = array();
				foreach ($hexarray as $hex => $num)
				{
					if ( ! isset($brightness[$hex]) )
					{
						$new_hex = $this->_normalize( $hex, $brightness, $delta );
						$brightness[$hex] = $new_hex;
					}
					else
					{
						$new_hex = $brightness[$hex];
					}

					if ($hex != $new_hex)
					{
						$hexarray[$hex] = 0;
						$hexarray[$new_hex] += $num;
					}
				}
			}

			arsort( $hexarray, SORT_NUMERIC );

			// convert counts to percentages
			foreach ($hexarray as $key => $value)
			{
				$hexarray[$key] = (float)$value / $total_pixel_count;
			}

			if ( $count > 0 )
			{
				// only works in PHP5
				// return array_slice( $hexarray, 0, $count, true );

				$arr = array();
				foreach ($hexarray as $key => $value)
				{
					if ($count == 0)
					{
						break;
					}
					$count--;
					$arr[$key] = $value;
				}
				return $arr;
			}
			else
			{
				return $hexarray;
			}

		}
		else
		{
			$this->error = "Image ".$img." does not exist or is unreadable";
			return false;
		}
	}

	function _normalize( $hex, $hexarray, $delta )
	{
		$lowest = 255;
		$highest = 0;
		$colors['red'] = hexdec( substr( $hex, 0, 2 ) );
		$colors['green']  = hexdec( substr( $hex, 2, 2 ) );
		$colors['blue'] = hexdec( substr( $hex, 4, 2 ) );

		if ($colors['red'] < $lowest)
		{
			$lowest = $colors['red'];
		}
		if ($colors['green'] < $lowest )
		{
			$lowest = $colors['green'];
		}
		if ($colors['blue'] < $lowest )
		{
			$lowest = $colors['blue'];
		}

		if ($colors['red'] > $highest)
		{
			$highest = $colors['red'];
		}
		if ($colors['green'] > $highest )
		{
			$highest = $colors['green'];
		}
		if ($colors['blue'] > $highest )
		{
			$highest = $colors['blue'];
		}

		// Do not normalize white, black, or shades of grey unless low delta
		if ( $lowest == $highest )
		{
			if ($delta <= 32)
			{
				if ( $lowest == 0 || $highest >= (255 - $delta) )
				{
					return $hex;
				}
			}
			else
			{
				return $hex;
			}
		}

		for (; $highest < 256; $lowest += $delta, $highest += $delta)
		{
			$new_hex = substr("0".dechex($colors['red'] - $lowest),-2).substr("0".dechex($colors['green'] - $lowest),-2).substr("0".dechex($colors['blue'] - $lowest),-2);

			if ( isset( $hexarray[$new_hex] ) )
			{
				// same color, different brightness - use it instead
				return $new_hex;
			}
		}

		return $hex;
	}

	function _find_adjacent( $hex, $gradients, $delta )
	{
		$red = hexdec( substr( $hex, 0, 2 ) );
		$green  = hexdec( substr( $hex, 2, 2 ) );
		$blue = hexdec( substr( $hex, 4, 2 ) );

		if ($red > $delta)
		{
			$new_hex = substr("0".dechex($red - $delta),-2).substr("0".dechex($green),-2).substr("0".dechex($blue),-2);
			if ( isset($gradients[$new_hex]) )
			{
				return $gradients[$new_hex];
			}
		}
		if ($green > $delta)
		{
			$new_hex = substr("0".dechex($red),-2).substr("0".dechex($green - $delta),-2).substr("0".dechex($blue),-2);
			if ( isset($gradients[$new_hex]) )
			{
				return $gradients[$new_hex];
			}
		}
		if ($blue > $delta)
		{
			$new_hex = substr("0".dechex($red),-2).substr("0".dechex($green),-2).substr("0".dechex($blue - $delta),-2);
			if ( isset($gradients[$new_hex]) )
			{
				return $gradients[$new_hex];
			}
		}

		if ($red < (255 - $delta))
		{
			$new_hex = substr("0".dechex($red + $delta),-2).substr("0".dechex($green),-2).substr("0".dechex($blue),-2);
			if ( isset($gradients[$new_hex]) )
			{
				return $gradients[$new_hex];
			}
		}
		if ($green < (255 - $delta))
		{
			$new_hex = substr("0".dechex($red),-2).substr("0".dechex($green + $delta),-2).substr("0".dechex($blue),-2);
			if ( isset($gradients[$new_hex]) )
			{
				return $gradients[$new_hex];
			}
		}
		if ($blue < (255 - $delta))
		{
			$new_hex = substr("0".dechex($red),-2).substr("0".dechex($green),-2).substr("0".dechex($blue + $delta),-2);
			if ( isset($gradients[$new_hex]) )
			{
				return $gradients[$new_hex];
			}
		}

		return $hex;
	}
}

/*
 * Die Funktion gibt den Array-Schlüssel der Farbe ($palette),
 * die am ehesten der Farbe $givenColor entspricht.
 * 
 * Returns the index of the palette-color which is most similar
 * to $givenColor.
 * 
 * $givenColor und die Einträge in $palette können entweder
 * Strings im Format (#)rrggbb
 * (z. B. "ff0000", "4da4f3" oder auch "#b5d7f3")
 * oder Arrays mit je einem Wert für Rot, Grün und Blau 
 * (z. B. $givenColor = array( 0xff, 0x00, 0x00 ) )
 * sein.
 * 
 * $givenColor and the colors in $palette should be either
 * formatted as (#)rrggbb
 * (e. g. "ff0000", "4da4f3" or "#b5d7f3")
 * or arrays with values for red, green and blue
 * (e. g. $givenColor = array( 0xff, 0x00, 0x00 ) )
 *
 * Referenzen/References:
 * function rgb2lab
 *   - http://www.f4.fhtw-berlin.de/~barthel/ImageJ/ColorInspector//HTMLHilfe/farbraumJava.htm
 *   - http://www.brucelindbloom.com/index.html?Eqn_RGB_to_XYZ.html
 *   - http://www.brucelindbloom.com/index.html?Eqn_XYZ_to_Lab.html
 *
 * function deltaE
 *   - http://www.brucelindbloom.com/index.html?Eqn_DeltaE_CMC.html
 */
function getNearestColor( $givenColor, $palette = array('blue' => '0000ff','red' => 'ff0000','green' => '00ff00','yellow' => 'ffff00','black' => '000000','white' => 'ffffff','orange' => 'ff8800','purple' => 'ff00ff', 'teal' => '00ffff')
	)
{
	if(!function_exists('rgb2lab'))
	{
		function rgb2lab($rgb) {
			$eps = 216/24389; $k = 24389/27;
			// reference white D50
			$xr = 0.964221; $yr = 1.0; $zr = 0.825211;
			// reference white D65
			#$xr = 0.95047; $yr = 1.0; $zr = 1.08883;

			// RGB to XYZ
			$rgb[0] = $rgb[0]/255; //R 0..1
			$rgb[1] = $rgb[1]/255; //G 0..1
			$rgb[2] = $rgb[2]/255; //B 0..1

			// assuming sRGB (D65)
			$rgb[0] = ($rgb[0] <= 0.04045)?($rgb[0]/12.92):pow(($rgb[0]+0.055)/1.055,2.4);
			$rgb[1] = ($rgb[1] <= 0.04045)?($rgb[1]/12.92):pow(($rgb[1]+0.055)/1.055,2.4);
			$rgb[2] = ($rgb[2] <= 0.04045)?($rgb[2]/12.92):pow(($rgb[2]+0.055)/1.055,2.4);

			// sRGB D50
			$x =  0.4360747*$rgb[0] + 0.3850649*$rgb[1] + 0.1430804*$rgb[2];
			$y =  0.2225045*$rgb[0] + 0.7168786*$rgb[1] + 0.0606169*$rgb[2];
			$z =  0.0139322*$rgb[0] + 0.0971045*$rgb[1] + 0.7141733*$rgb[2];
			// sRGB D65
			/*$x =  0.412453*$rgb[0] + 0.357580*$rgb[1] + 0.180423*$rgb[2];
			$y =  0.212671*$rgb[0] + 0.715160*$rgb[1] + 0.072169*$rgb[2];
			$z =  0.019334*$rgb[0] + 0.119193*$rgb[1] + 0.950227*$rgb[2];*/

			// XYZ to Lab
			$xr = $x/$xr; $yr = $y/$yr; $zr = $z/$zr;

			$fx = ($xr > $eps)?pow($xr, 1/3):($fx = ($k * $xr + 16) / 116); $fy = ($yr > $eps)?pow($yr, 1/3):($fy = ($k * $yr + 16) / 116); $fz = ($zr > $eps)?pow($zr, 1/3):($fz = ($k * $zr + 16) / 116);

			$lab = array();
			$lab[] = round(( 116 * $fy ) - 16); $lab[] = round(500*($fx-$fy)); $lab[] = round(200*($fy-$fz));      
			return $lab;
		} // function rgb2lab
	}

	if(!function_exists('deltaE'))
	{
		function deltaE($lab1, $lab2)
		{
			// CMC 1:1
			$l = 1; $c = 1;

			$c1 = sqrt($lab1[1]*$lab1[1]+$lab1[2]*$lab1[2]); $c2 = sqrt($lab2[1]*$lab2[1]+$lab2[2]*$lab2[2]);

			$h1 = (((180000000/M_PI) * atan2($lab1[1],$lab1[2]) + 360000000) % 360000000)/1000000;

			$t = (164 <= $h1 AND $h1 <= 345)?(0.56 + abs(0.2 * cos($h1+168))):(0.36 + abs(0.4 * cos($h1+35)));
			$f = sqrt(pow($c1,4)/(pow($c1,4) + 1900));

			$sl = ($lab1[0] < 16)?(0.511):((0.040975*$lab1[0])/(1 + 0.01765*$lab1[0]));
			$sc = (0.0638 * $c1)/(1 + 0.0131 * $c1) + 0.638;
			$sh = $sc * ($f * $t + 1 -$f);

			return sqrt( pow(($lab1[0]-$lab2[0])/($l * $sl),2) + pow(($c1-$c2)/($c * $sc),2) + pow(sqrt(($lab1[1]-$lab2[1])*($lab1[1]-$lab2[1]) + ($lab1[2]-$lab2[2])*($lab1[2]-$lab2[2]) + ($c1-$c2)*($c1-$c2))/$sh,2) );
		} // function deltaE
	}

	if(!function_exists('colorDistance'))
	{
		function colorDistance($lab1,$lab2)
		{
			return sqrt(($lab1[0]-$lab2[0])*($lab1[0]-$lab2[0])+($lab1[1]-$lab2[1])*($lab1[1]-$lab2[1])+($lab1[2]-$lab2[2])*($lab1[2]-$lab2[2]));
		}
	}

	if(!function_exists('str2rgb'))
	{
		function str2rgb($str)
		{
			$str = preg_replace('~[^0-9a-f]~','',$str);
			$rgb = str_split($str,2);
			for($i=0;$i<3;$i++)
				$rgb[$i] = intval($rgb[$i],16);

			return $rgb;
		} // function str2rgb
	}

	// split into RGB, if not already done
	$givenColorRGB = is_array($givenColor)?$givenColor:str2rgb($givenColor);
	$min = 0xffff;
	$return = NULL;

	foreach($palette as $key => $color)
	{
		// split into RGB
		$color = is_array($color)?$color:str2rgb($color);
		// deltaE
		#if($min >= ($deltaE = deltaE(rgb2lab($color),rgb2lab($givenColorRGB))))
		// euclidean distance
		if($min >= ($deltaE = colorDistance(rgb2lab($color),rgb2lab($givenColorRGB))))
		{
			$min = $deltaE;
			$return = $key;
		}
	}

	return $return;
}



    //& quoted form of my workPathPosix & " " & quoted form of my pathToResources & " " & quoted form of my libraryPath & " > " & my workPathPosix &
    var_dump($argv);
    $Photos = new Photos($argv[1], $argv[3], $argv[4], $argv[5], $argv[6], $argv[7], $argv[8]);  //   $Photos = new Photos("/Users/andersbj/Pictures/demo.photoslibrary", "/Users/andersbj/Dropbox/Brattoo/_keyword_extract_lab/");
//$Photos = new Photos($argv[1], $argv[2], $argv[3], $argv[4]);
//$Photos = new Photos("/Users/andersbj/Pictures/demo.photoslibrary", "/Users/andersbj/Dropbox/Brattoo/_keyword_extract_lab/");
//$Photos = new Photos("/Users/andersbj/Pictures/Bilder-bibliotek.photoslibrary", "/Users/andersbj/Dropbox/Brattoo/_keyword_extract_lab/");
//$Photos = new Photos("/Users/propaganda/Pictures/demo.photoslibrary", "/Users/andersbj/Dropbox/Brattoo/_keyword_extract_lab/");
